[Libreoffice-commits] .: sfx2/inc sfx2/source

Tor Lillqvist tml at kemper.freedesktop.org
Wed Apr 6 00:36:11 PDT 2011


 sfx2/inc/bitset.hxx                 |    2 
 sfx2/inc/macro.hxx                  |   99 +++++++++++++++----------------
 sfx2/inc/sfx2/QuerySaveDocument.hxx |    2 
 sfx2/inc/sfx2/bindings.hxx          |   75 +++++++++++-------------
 sfx2/inc/sfx2/chalign.hxx           |   26 ++++----
 sfx2/inc/sfx2/childwin.hxx          |   58 +++++++++---------
 sfx2/inc/sfx2/cntids.hrc            |   48 +++++++--------
 sfx2/inc/sfx2/ctrlitem.hxx          |   11 +--
 sfx2/inc/sfx2/dispatch.hxx          |   71 ++++++++++------------
 sfx2/inc/sfx2/docfac.hxx            |   26 ++++----
 sfx2/inc/sfx2/doctempl.hxx          |    7 --
 sfx2/inc/sfx2/filedlghelper.hxx     |    6 -
 sfx2/inc/sfx2/frame.hxx             |   21 +++---
 sfx2/inc/sfx2/frmdescr.hxx          |   26 +++-----
 sfx2/inc/sfx2/frmhtml.hxx           |    2 
 sfx2/inc/sfx2/hintpost.hxx          |   17 ++---
 sfx2/inc/sfx2/htmlmode.hxx          |   22 +++----
 sfx2/inc/sfx2/linkmgr.hxx           |   56 +++++++++---------
 sfx2/inc/sfx2/linksrc.hxx           |    2 
 sfx2/inc/sfx2/lnkbase.hxx           |   20 +++---
 sfx2/inc/sfx2/mgetempl.hxx          |    8 +-
 sfx2/inc/sfx2/minarray.hxx          |    2 
 sfx2/inc/sfx2/mnumgr.hxx            |    4 -
 sfx2/inc/sfx2/msg.hxx               |  112 +++++++++++++++++++-----------------
 sfx2/inc/sfx2/new.hxx               |    5 -
 sfx2/inc/sfx2/objsh.hxx             |   40 ++++++------
 sfx2/inc/sfx2/sfxhtml.hxx           |   44 ++++++--------
 sfx2/inc/sfx2/sfxsids.hrc           |   20 +++---
 sfx2/inc/sfx2/tabdlg.hxx            |   23 +++----
 sfx2/inc/sfx2/tbxctrl.hxx           |   25 +++-----
 sfx2/inc/sfx2/viewsh.hxx            |   65 +++++++++-----------
 sfx2/source/dialog/styledlg.cxx     |    4 -
 sfx2/source/dialog/tabdlg.cxx       |    1 
 sfx2/source/doc/objxtor.cxx         |    2 
 sfx2/source/view/frame.cxx          |    2 
 35 files changed, 469 insertions(+), 485 deletions(-)

New commits:
commit fba30a7971744bfbc9891924b7ad5b51e3c2b685
Author: Albert Thuswaldner <albert.thuswaldner at gmail.com>
Date:   Wed Apr 6 10:35:15 2011 +0300

    Additional translations of German comments

diff --git a/sfx2/inc/bitset.hxx b/sfx2/inc/bitset.hxx
index 15fa1e1..f66de4b 100644
--- a/sfx2/inc/bitset.hxx
+++ b/sfx2/inc/bitset.hxx
@@ -197,7 +197,7 @@ inline sal_Bool BitSet::IsRealSubSet( const BitSet& ) const
 }
 //--------------------------------------------------------------------
 
-// detsermines if the other bitset is a superset or equal
+// determines if the other bitset is a superset or equal
 
 inline sal_Bool BitSet::IsSubSet( const BitSet& ) const
 {
diff --git a/sfx2/inc/macro.hxx b/sfx2/inc/macro.hxx
index a7737b9..a301696 100644
--- a/sfx2/inc/macro.hxx
+++ b/sfx2/inc/macro.hxx
@@ -17,11 +17,11 @@ class SfxMacro;
 
 class SfxMacroStatement
 {
-    sal_uInt16				nSlotId;	// ausgef"uhrte Slot-Id oder 0, wenn manuell
-    ::com::sun::star::uno::Sequence < ::com::sun::star::beans::PropertyValue > aArgs;      // aktuelle Parameter, falls nSlotId != 0
-    String				aStatement; // Statement in BASIC-Syntax (ggf. mit CR/LF)
-    sal_Bool				bDone;  	// auskommentieren wenn kein Done() gerufen
-    void*				pDummy;		// f"ur alle F"alle zum kompatibel bleiben
+    sal_uInt16				nSlotId;	// performed Slot-Id or 0, if manually
+    ::com::sun::star::uno::Sequence < ::com::sun::star::beans::PropertyValue > aArgs;      // current Parameter, in case nSlotId != 0
+    String				aStatement; // Statement in BASIC-Syntax (if necessary with CR/LF)
+    sal_Bool				bDone;  	// comment out if no Done() is called
+    void*				pDummy;		// for all cases, to remain compatible
 
 #ifdef _SFXMACRO_HXX
 private:
@@ -59,11 +59,10 @@ public:
 
 inline sal_uInt16 SfxMacroStatement::GetSlotId() const
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Liefert die Slot-Id die das Statement beim Abspielen wieder ausf"uhren
-    soll oder 0, falls das Statement manuell (<SFX_SLOT_RECORDMANUAL>)
-    aufgezeichnet wurde.
+    Returns the Slot-Id which the Statement should redo when called or 0
+    if the Statement (<SFX_SLOT_RECORDMANUAL>) was recorded manually.
 */
 
 {
@@ -74,14 +73,13 @@ inline sal_uInt16 SfxMacroStatement::GetSlotId() const
 
 inline const ::com::sun::star::uno::Sequence < ::com::sun::star::beans::PropertyValue >& SfxMacroStatement::GetArgs() const
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Liefert die Parameter mit denen Statement ausgef"uhrt wurde oder 0,
-    falls das Statement	manuell (<SFX_SLOT_RECORDMANUAL>) aufgezeichnet
-    wurde.
+    Returns the Parameter which was used in the call of the Statement or 0
+    if the Statement (<SFX_SLOT_RECORDMANUAL>) was recorded manually
 
-    Der R"uckgabewert geh"ort dem SfxMacroStatement und ist nur im
-    unmittelbar aufrufenden Stackframe g"ultig.
+    The returned value belongs to the SfxMacroStatement and is only valid
+    to the Stackframe.
 */
 
 {
@@ -92,11 +90,11 @@ inline const ::com::sun::star::uno::Sequence < ::com::sun::star::beans::Property
 
 inline sal_Bool	SfxMacroStatement::IsDone() const
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Liefert TRUE, wenn das Statement wirklich ausgef"uhrt wurde,
-    also z.B. nicht vom Benutzer abgebrochen wurde. Wurde es nicht
-    wirklich ausgef"uhrt, dann wird es im BASIC-Source auskommentiert.
+    Returns TRUE only if the Statement really was excecuted, so for instance
+    not if it was canceled by the user. If it was not excecuted the
+    BASIC-Source would be commented out.
 */
 
 {
@@ -105,18 +103,18 @@ inline sal_Bool	SfxMacroStatement::IsDone() const
 
 //--------------------------------------------------------------------
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Liefert das Statement in BASIC-Syntax. Wurde das Makro manuell erzeugt,
-    wird genau der im Konstruktor angegebene String zur"uckgegeben, sonst
-    der generierte Source-Code.
+    Returns the Statement in BASIC-Syntax. If the Macro was created manually,
+    the string will be returned exactly as given in the constructor, else the
+    generated Source-Code is returned.
 
-    Bei beiden Arten ist es m"oglich, da\s mehrere BASIC-Statements, jeweils
-    mit CR/LF getrennt in dem String enthalten sind, da ein SFx-Statement
-    ggf. in mehrere BASIC-Statements "ubersetzt wird.
+    It is possible in both of the above cases that several BASIC-Statements,
+    each contains CR / LF separators in the string, since a SFx statement
+    is translated if necessary into several BASIC statements.
 
-    Statements f"ur die nicht <SfxRequest::Done()> gerufen wurde, werden
-    mit einem vorangestellten 'rem' gekennzeichnet.
+    Statements for which <SfxRequest::Done()> was not called are marked
+    with a preceding 'rem'.
 */
 
 inline const String& SfxMacroStatement::GetStatement() const
@@ -128,41 +126,38 @@ inline const String& SfxMacroStatement::GetStatement() const
 
 enum SfxMacroMode
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Mit diesem enum wird bestimmt, ob eine <SfxMacro>-Instanz zum
-    absoluten oder relativen Recorden erzeugt wurde, oder um ein
-    existierendendes Makro zu Referenzieren.
+    By using this enum it is determined, if a <SfxMacro>-Instance was created
+    by absolute or relative recording, or to create a reference to a existing
+    macro.
 */
 
 {
-    SFX_MACRO_EXISTING,			/*	es handelt sich um ein bereits
-                                    exitistierendes Makro, welches lediglich
-                                    referenziert wird */
-
-    SFX_MACRO_RECORDINGABSOLUTE,/*	dieses Makro soll aufgezeichnet werden,
-                                    wobei die betroffenen Objekte m"oglichst
-                                    direkt angesprochen werden sollen
-                                    (Beispiel: "[doc.sdc]") */
-
-    SFX_MACRO_RECORDINGRELATIVE/*   dieses Makro soll aufgezeichnet werden,
-                                    wobei die betroffenen Objekte so
-                                    angesprochen werden sollen, da\s sich das
-                                    Abspielen auf die dann g"ultige Selektion
-                                    bezieht (Beispiel: "ActiveDocument()") */
+    SFX_MACRO_EXISTING,           /* Indicates that it is a existing
+                                     macro, which will only referenced */
+
+    SFX_MACRO_RECORDINGABSOLUTE,  /* This macro shall be recorded so that the
+                                     affected objects are to be addressed as
+                                     directly as possible (example: "[doc.sdc]") */
+
+    SFX_MACRO_RECORDINGRELATIVE   /* This macro is recorded and the affected
+                                     objects are addressed in such a way so
+                                     that when running the macro it refers to
+                                     a vaild selection
+                                     (example:" active document () ") */
 };
 
 //====================================================================
 
 class SfxMacro
 
-/*	[Beschreibung]
+/*  [Description]
 
-    "Uber diese Klasse (bzw. genaugenommen ihre Subklassen) wird zum
-    einen die Lokation einer BASIC-Funktion (also in welcher Library,
-    in welchem Modul sowie der Funktions-Name) beschrieben, als auch
-    ein aufzuzeichnendes Makro w"ahrend der Aufzeichnung zwischen-
-    gespeichert.
+    Through using this class (and in fact its subclasses) the location of a
+    BASIC function will be discribed (also in which Library, in which module
+    and the Function name) as well as temporary storing a macro during the
+    recording.
 */
 
 {
diff --git a/sfx2/inc/sfx2/QuerySaveDocument.hxx b/sfx2/inc/sfx2/QuerySaveDocument.hxx
index bc4dbfc..1d8bd38 100644
--- a/sfx2/inc/sfx2/QuerySaveDocument.hxx
+++ b/sfx2/inc/sfx2/QuerySaveDocument.hxx
@@ -33,7 +33,7 @@
 
 class Window;
 class String;
-/** opens the generell query save document dialog.
+/** Opens the general query save document dialog.
     @param	_pParent
         The parent window.
     @_rTitle
diff --git a/sfx2/inc/sfx2/chalign.hxx b/sfx2/inc/sfx2/chalign.hxx
index fd62dc4..3e74c43 100644
--- a/sfx2/inc/sfx2/chalign.hxx
+++ b/sfx2/inc/sfx2/chalign.hxx
@@ -30,32 +30,32 @@
 
 #include <tools/solar.h>
 
-// Neue Reihenfolge: zuerst Navigationsleiste, dann senkrecht angedockte
-// ChildWindows (Explorer!), dann horizontal angedockte ChildWindows (Browser!),
-// dann die Formatleiste, die Statuszeile, am Ende die Werkzeugleiste.
+// New order: first, navigation bar, then vertically docked child windows
+// (Explorer!), then horizontally docked child windows (Browser!),
+// then the format bar, status bar, and at the end of the toolbar.
 
 enum SfxChildAlignment
 {
-    SFX_ALIGN_HIGHESTTOP,       // z.B. Navigationsleiste
+    SFX_ALIGN_HIGHESTTOP,       // for example Navigation bar
     SFX_ALIGN_LOWESTBOTTOM,
     SFX_ALIGN_FIRSTLEFT,
     SFX_ALIGN_LASTRIGHT,
-    SFX_ALIGN_LEFT,				// z.B. SplitWindow
+    SFX_ALIGN_LEFT,             // for example SplitWindow
     SFX_ALIGN_RIGHT,
     SFX_ALIGN_LASTLEFT,
     SFX_ALIGN_FIRSTRIGHT,
-    SFX_ALIGN_TOP,				// z.B. Hyperlink-Builder, SplitWindow
-    SFX_ALIGN_BOTTOM,			// z.B. SplitWindow
-    SFX_ALIGN_TOOLBOXTOP,		// z.B. Objektleiste
+    SFX_ALIGN_TOP,              // for example Hyperlink-Builder, SplitWindow
+    SFX_ALIGN_BOTTOM,           // for example SplitWindow
+    SFX_ALIGN_TOOLBOXTOP,       // for example Objekt bar
     SFX_ALIGN_TOOLBOXBOTTOM,
-    SFX_ALIGN_LOWESTTOP,		// z.B. Calc-Rechenleiste
-    SFX_ALIGN_HIGHESTBOTTOM,    // z.B. Statusleiste
-    SFX_ALIGN_TOOLBOXLEFT,		// z.B. Werkzeugleiste
+    SFX_ALIGN_LOWESTTOP,        // for example Calc bar
+    SFX_ALIGN_HIGHESTBOTTOM,    // for example Status bar
+    SFX_ALIGN_TOOLBOXLEFT,      // for example Tool bar
     SFX_ALIGN_TOOLBOXRIGHT,
-    SFX_ALIGN_NOALIGNMENT		// alle FloatingWindows
+    SFX_ALIGN_NOALIGNMENT       // all FloatingWindows
 };
 
-// "Uberpr"uft, ob ein g"ultiges Alignment verwendet wird
+// Verifies that a valid alignment is used
 inline sal_Bool SfxChildAlignValid( SfxChildAlignment eAlign )
 {
     return ( eAlign >= SFX_ALIGN_HIGHESTTOP && eAlign <= SFX_ALIGN_NOALIGNMENT );
diff --git a/sfx2/inc/sfx2/childwin.hxx b/sfx2/inc/sfx2/childwin.hxx
index 9d6d93d..509a7c2 100644
--- a/sfx2/inc/sfx2/childwin.hxx
+++ b/sfx2/inc/sfx2/childwin.hxx
@@ -48,17 +48,18 @@ class SfxChildWindow;
 class SfxChildWindowContext;
 class SfxChildWinContextArr_Impl;
 
-#define SFX_CHILDWIN_ZOOMIN       0x01		// ganz eingeklapptes Float
-#define SFX_CHILDWIN_SMALL		  0x02		// halb eingeklapptes Float
-#define SFX_CHILDWIN_FORCEDOCK    0x04		// Float verboten
-#define SFX_CHILDWIN_AUTOHIDE	  0x08		// DockingWindow im AutoHide-Modus
-#define SFX_CHILDWIN_TASK         0x10		// ChildWindow innerhalb der Task
-#define SFX_CHILDWIN_CANTGETFOCUS 0x20		// ChildWindow kann keinen Focus bekommen
+#define SFX_CHILDWIN_ZOOMIN          0x01  // Fully retracted Float
+#define SFX_CHILDWIN_SMALL           0x02  // Half retracted Float
+#define SFX_CHILDWIN_FORCEDOCK       0x04  // Float forbidden
+#define SFX_CHILDWIN_AUTOHIDE        0x08  // DockingWindow in AutoHide mode
+#define SFX_CHILDWIN_TASK            0x10  // ChildWindow inside the Task
+#define SFX_CHILDWIN_CANTGETFOCUS    0x20  // ChildWindow can not get focus
 #define SFX_CHILDWIN_ALWAYSAVAILABLE 0x40   // ChildWindow is never disabled
-#define SFX_CHILDWIN_NEVERHIDE    0x80      // ChildWindow is can always made visible/is visible
+#define SFX_CHILDWIN_NEVERHIDE       0x80  // ChildWindow is can always made 
+                                           // visible/is visible
 #define CHILDWIN_NOPOS		      USHRT_MAX
 
-// Konfiguration eines ChildWindows
+// ChildWindow Configuration 
 struct SfxChildWinInfo
 {
     sal_Bool				bVisible;
@@ -80,21 +81,21 @@ struct SfxChildWinInfo
                                            sal_uInt16				*pPos = 0 ) const;
 };
 
-// Factory-Methode eines ChildWindows
+// ChildWindow factory methods
 typedef SfxChildWindow* (*SfxChildWinCtor)( ::Window *pParentWindow,
                                             sal_uInt16 nId,
                                             SfxBindings *pBindings,
                                             SfxChildWinInfo *pInfo);
 
-// Factory-Methode eines ChildWindowsContexts
+// ChildWindowsContexts factory methods 
 typedef SfxChildWindowContext* (*SfxChildWinContextCtor)( ::Window *pParentWindow,
                                             SfxBindings *pBindings,
                                             SfxChildWinInfo *pInfo);
 struct SfxChildWinContextFactory
 {
-    SfxChildWinContextCtor	pCtor;      // Factory-Methode
-    sal_uInt16					nContextId;	// Identifier f"ur das SfxInterface
-    SfxChildWinInfo 		aInfo;		// Konfiguration
+    SfxChildWinContextCtor  pCtor;      // Factory method
+    sal_uInt16              nContextId; // Idenifier for SfxInterface
+    SfxChildWinInfo         aInfo;      // Configuration
 
     SfxChildWinContextFactory( SfxChildWinContextCtor pTheCtor, sal_uInt16 nID )
         : pCtor(pTheCtor)
@@ -106,11 +107,11 @@ SV_DECL_PTRARR_DEL( SfxChildWinContextArr_Impl, SfxChildWinContextFactory*, 2, 2
 
 struct SfxChildWinFactory
 {
-    SfxChildWinCtor 	pCtor;			// Factory-Methode
+    SfxChildWinCtor            pCtor;  // Factory method
     sal_uInt16				nId;            // ChildWindow-Id ( SlotId )
-    SfxChildWinInfo 	aInfo;          // Konfiguration
-    sal_uInt16				nPos;           // ggf. Position im UI
-    SfxChildWinContextArr_Impl *pArr;	// Array f"ur Contexte
+    SfxChildWinInfo            aInfo;  // Configuration
+    sal_uInt16                  nPos;  // Position in UI
+    SfxChildWinContextArr_Impl *pArr;  // Array for Contexts
 
     SfxChildWinFactory( SfxChildWinCtor pTheCtor, sal_uInt16 nID,
             sal_uInt16 n )
@@ -162,13 +163,13 @@ class SFX2_DLLPUBLIC SfxChildWindow
     sal_uInt16				nType;			// ChildWindow-Id
 
 protected:
-    SfxChildAlignment   	eChildAlignment;// aktuelles ::com::sun::star::drawing::Alignment
-    ::Window*             	pWindow;		// eigentlicher Inhalt
-    SfxChildWindow_Impl*	pImp;			// Imp-Daten
+    SfxChildAlignment           eChildAlignment; // Current ::com::sun::star::drawing::Alignment
+    ::Window*                   pWindow;         // actual contents
+    SfxChildWindow_Impl*        pImp;            // Implementation data
 
 private:
-    SfxChildWindowContext*	pContext;		// bei kontextsensitiven ChildWindows:
-                                            // weiteres window in pWindow
+    SfxChildWindowContext*      pContext;        // With context-sensitive ChildWindows:
+                                                 // Annother window in pWindow
     SAL_DLLPRIVATE SfxChildWindowContext*
                         GetContext() const
                         { return pContext; }
@@ -240,19 +241,19 @@ public:
 };
 
 //------------------------------------------------------------------
-//! demn"achst hinf"allig !
+//! soon obsolete !
 #define SFX_DECL_CHILDWINDOW_CONTEXT(Class) \
         static	SfxChildWindowContext* CreateImpl(::Window *pParent, \
                     SfxBindings *pBindings, SfxChildWinInfo* pInfo ); \
         static	void RegisterChildWindowContext(SfxModule *pMod=0); \
 
-//! Das Macro der Zukunft ...
+//! The Macro of the future ...
 #define SFX_DECL_CHILDWINDOWCONTEXT(Class) \
         static	SfxChildWindowContext* CreateImpl(::Window *pParent, \
                     SfxBindings *pBindings, SfxChildWinInfo* pInfo ); \
         static	void RegisterChildWindowContext(sal_uInt16, SfxModule *pMod=0); \
 
-//! demn"achst hinf"allig !
+//! soon obsolete !
 #define SFX_IMPL_CHILDWINDOW_CONTEXT(Class, MyID, ShellClass) \
         SfxChildWindowContext* Class::CreateImpl( ::Window *pParent, \
                 SfxBindings *pBindings, SfxChildWinInfo* pInfo ) \
@@ -270,9 +271,10 @@ public:
             SfxChildWindowContext::RegisterChildWindowContext(pMod, MyID, pFact); \
         }
 
-//! Das Macro der Zukunft ...
-// CreateImpl mu\s noch als Parameter die Factory mitbekommen wg. ContextId
-// Solange wird diese Id auf 0 gesetzt und in SfxChildWindow::CreateContext gepatched
+//! The Macro of the future ...
+// As a parameter and because of ContextId, CreateImpl must be handed the 
+// factory. As long as Id is set to 0 and patched in 
+// SfxChildWindow::CreateContext 
 #define SFX_IMPL_CHILDWINDOWCONTEXT(Class, MyID) \
         SfxChildWindowContext* Class::CreateImpl( ::Window *pParent, \
                 SfxBindings *pBindings, SfxChildWinInfo* pInfo ) \
diff --git a/sfx2/inc/sfx2/cntids.hrc b/sfx2/inc/sfx2/cntids.hrc
index 80e0265..dfc9fe0 100755
--- a/sfx2/inc/sfx2/cntids.hrc
+++ b/sfx2/inc/sfx2/cntids.hrc
@@ -39,9 +39,9 @@
 // Slot-ID's -----------------------------------------------------------------
 
 #ifndef SID_SFX_START
-// HACK() - SID's duerfen nicht o.w. ihren numerischen Wert aendern,
-//			sfxsids.hrc darf aber nicht included werden!!! Loesung: sfxsids.hrc
-//			"tiefer legen" - z.B. svtools???
+// HACK() - SID's may not change its numerical value just like that,
+//          sfxsids.hrc may not be included!!! Solution: sfxsids.hrc
+//          include it on a lower level - for example svtools???
 #define SID_SFX_START					5000
 #endif
 #define SID_TITLE						(SID_SFX_START + 307)
@@ -349,24 +349,24 @@
 
 // Tabpage-Ids ---------------------------------------------------------------
 
-#define CNT_TABPAGE_GENERAL					1  // "Allgemein"
-#define CNT_TABPAGE_SERVER_SETTINGS     	2  // "Server"
-#define CNT_TABPAGE_RULES					3  // "Regeln"
-#define CNT_TABPAGE_VIEW_PROPERTIES			4  // "Ansicht"
-#define CNT_TABPAGE_CONTENT_PROPERTIES		5  // "Inhalte"
-#define CNT_TABPAGE_SUBSCRIBE				6  // "Abonniert"
-#define CNT_TABPAGE_RECIPIENT_STATE			7  // "Status" (Outtray-Msgs)
-#define CNT_TABPAGE_RECV_POP3				8  // "Empfangen" fuer POP3
-#define CNT_TABPAGE_RECV_NNTP				9  // - " - fuer NNTP-Accounts
-#define CNT_TABPAGE_RECV_IMAP				10 // - " - fuer IMAP-Accounts
-#define CNT_TABPAGE_RECV_VIM				11 // - " - fuer VIM-Accounts
-#define CNT_TABPAGE_SEND_SMTP				12 // "SMTP"
-#define CNT_TABPAGE_SEND_NNTP				13 // "NNTP"
-#define CNT_TABPAGE_SEND_VIM				14 // "VIM"
-#define CNT_TABPAGE_MAIL_NEWS_SEND			15 // "Versenden"
+#define CNT_TABPAGE_GENERAL                     1  
+#define CNT_TABPAGE_SERVER_SETTINGS             2  
+#define CNT_TABPAGE_RULES                       3
+#define CNT_TABPAGE_VIEW_PROPERTIES             4
+#define CNT_TABPAGE_CONTENT_PROPERTIES          5
+#define CNT_TABPAGE_SUBSCRIBE                   6
+#define CNT_TABPAGE_RECIPIENT_STATE             7
+#define CNT_TABPAGE_RECV_POP3                   8
+#define CNT_TABPAGE_RECV_NNTP                   9
+#define CNT_TABPAGE_RECV_IMAP                   10
+#define CNT_TABPAGE_RECV_VIM                    11
+#define CNT_TABPAGE_SEND_SMTP                   12
+#define CNT_TABPAGE_SEND_NNTP                   13
+#define CNT_TABPAGE_SEND_VIM                    14
+#define CNT_TABPAGE_MAIL_NEWS_SEND              15
 #define CNT_TABPAGE_SEARCH_CRITERIA 		16
 #define CNT_TABPAGE_SEARCH_LOCATIONS 		17
-#define CNT_TABPAGE_PROJECT_DATAEXCHANGE	18 // "Datenaustausch"
+#define CNT_TABPAGE_PROJECT_DATAEXCHANGE        18
 #define CNT_TABPAGE_SBOX_LOCATION			19
 #define CNT_TABPAGE_SBOX_SUBSCRIBTION		20
 #define CNT_TABPAGE_SBOX_SCHEDULE			21
@@ -377,12 +377,12 @@
 #define CNT_TABPAGE_SBOX_SDC_GENERAL		26
 #define CNT_TABPAGE_SBOX_CDF_SUBSCRIBTION	27
 #define CNT_TABPAGE_BACKGROUND			28
-#define CNT_TABPAGE_HEADER			29	// "Kopfzeilen" - Header bei Mail/News etc.
-#define CNT_TABPAGE_DESCRIPTION			30	// "Beschreibung" - Header im Filesys
+#define CNT_TABPAGE_HEADER                      29
+#define CNT_TABPAGE_DESCRIPTION                 30
 #define CNT_TABPAGE_FONT			31
-#define CNT_TABPAGE_FOLDER_BMK			32	// Link auf Ordner
-#define CNT_TABPAGE_DOCUMENT_BMK		33	// Link auf Dokument
-#define CNT_TABPAGE_WEBVIEW				34	// Web-Ansicht
+#define CNT_TABPAGE_FOLDER_BMK                  32
+#define CNT_TABPAGE_DOCUMENT_BMK                33
+#define CNT_TABPAGE_WEBVIEW                     34
 
 
 #define DEF_WIDTH_FROM						150
diff --git a/sfx2/inc/sfx2/ctrlitem.hxx b/sfx2/inc/sfx2/ctrlitem.hxx
index f38516e..b494e8a 100644
--- a/sfx2/inc/sfx2/ctrlitem.hxx
+++ b/sfx2/inc/sfx2/ctrlitem.hxx
@@ -41,30 +41,29 @@ class SFX2_DLLPUBLIC SfxControllerItem
 {
 private:
     sal_uInt16				nId;
-    SfxControllerItem*	pNext; // zu benachrichtigendes weiteres ControllerItem
+    SfxControllerItem*	pNext; // to notify next ControllerItem
     SfxBindings*		pBindings;
 
 protected:
-//#if defined( DBG_UTIL ) && defined( _SOLAR__PRIVATE )
 #if defined( DBG_UTIL )
     SAL_DLLPRIVATE void CheckConfigure_Impl( sal_uIntPtr nType );
 #endif
 
 public:
     SfxBindings &		GetBindings() {
-                            DBG_ASSERT(pBindings, "keine Bindings");
+                            DBG_ASSERT(pBindings, "no Bindings");
                             return *pBindings;
                         }
     const SfxBindings &	GetBindings() const {
-                            DBG_ASSERT(pBindings, "keine Bindings");
+                            DBG_ASSERT(pBindings, "no Bindings");
                             return *pBindings;
                         }
 
-                        SfxControllerItem(); // fuer arrays
+                        SfxControllerItem(); // for arrays
                         SfxControllerItem( sal_uInt16 nId, SfxBindings & );
     virtual 			~SfxControllerItem();
 
-    void				Bind( sal_uInt16 nNewId, SfxBindings * = 0);	// in SfxBindings registrieren
+    void				Bind( sal_uInt16 nNewId, SfxBindings * = 0);	// Register in SfxBindings
     void				UnBind();
     void				ReBind();
     sal_Bool				IsBound() const;
diff --git a/sfx2/inc/sfx2/dispatch.hxx b/sfx2/inc/sfx2/dispatch.hxx
index b3d1745..5e7dd33 100644
--- a/sfx2/inc/sfx2/dispatch.hxx
+++ b/sfx2/inc/sfx2/dispatch.hxx
@@ -111,7 +111,7 @@ class SFX2_DLLPUBLIC SfxDispatcher
     sal_Bool							bFlushed;
 
 private:
-    // auf temporaer ausgewerteten Todos suchen
+    // Search for temporary evaluated Todos
     SAL_DLLPRIVATE sal_Bool CheckVirtualStack( const SfxShell& rShell, sal_Bool bDeep );
 
 #ifndef _SFX_HXX
@@ -131,8 +131,8 @@ friend class SfxBindings;
 friend class SfxStateCache;
 friend class SfxPopupMenuManager;
 friend class SfxHelp;
-                        // Fuer die Bindings: Finden einer Message; Level fuer
-                        // erneuten Zugriff
+                        // For bindings: Finding the Message; 
+                        // level for re-access
     SAL_DLLPRIVATE sal_Bool _TryIntercept_Impl( sal_uInt16 nId, SfxSlotServer &rServer, sal_Bool bModal );
     sal_Bool				_FindServer( sal_uInt16 nId, SfxSlotServer &rServer, sal_Bool bModal );
     sal_Bool				_FillState( const SfxSlotServer &rServer,
@@ -261,11 +261,10 @@ public:
 
 inline sal_Bool SfxDispatcher::IsFlushed() const
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Mit dieser Methode l"a"st sich erfragen, ob der Stack des
-    SfxDispatchers geflusht ist, oder noch Push- oder Pop-Befehle
-    ausstehen.
+    This method checks if the stack of the SfxDispatchers is flushed, or if 
+    push- or pop- commands are pending.
 */
 
 {
@@ -276,13 +275,12 @@ inline sal_Bool SfxDispatcher::IsFlushed() const
 
 inline void SfxDispatcher::Flush()
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Diese Methode f"uhrt ausstehenden Push- und Pop-Befehle aus.
-    F"ur <SfxShell>s, die dabei neu auf den Stack kommen, wird
-    <SfxShell::Activate(sal_Bool)> mit bMDI == sal_True aufgerufen, f"ur
-    SfxShells, die vom Stack entfernt werden, wird <SfxShell::Deactivate(sal_Bool)>
-    mit bMDI == sal_True aufgerufen.
+    This method performs outstanding push- and pop- commands. For <SfxShell>s, 
+    which are new on the stack, the <SfxShell::Activate(sal_Bool)> is invoked with 
+    bMDI == sal_True, for SfxShells that are removed from the stack, the 
+    <SfxShell::Deactivate(sal_Bool)> is invoked with bMDI == sal_True
 */
 
 {
@@ -293,14 +291,15 @@ inline void SfxDispatcher::Flush()
 
 inline void SfxDispatcher::Push( SfxShell& rShell )
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Mit dieser Methode wird eine <SfxShell> auf den SfxDispatcher
-    gepusht. Die SfxShell wird zun"achst zum pushen vermerkt und
-    es wird ein Timer aufgesetzt. Erst bei Ablauf des Timers wird
-    tats"achlich gepusht (<SfxDispatcher::Flush()>) und die <SfxBindings>
-    werden invalidiert. W"ahrend der Timer l"auft gleichen sich
-    entgegengesetzte Push und Pop Befehle mit derselben SfxShell aus.
+    With this method, a <SfxShell> pushed on to the SfxDispatcher. 
+    The SfxShell is first marked for push and a timer is set up. 
+    First when the timer has couted down to zero the push 
+    ( <SfxDispatcher::Flush()> ) is actually performed and the 
+    <SfxBindings> is invalidated. While the timer is counting down 
+    the opposing push and pop commands on the same SfxShell are 
+    leveled out.
 */
 
 {
@@ -311,21 +310,18 @@ inline void SfxDispatcher::Push( SfxShell& rShell )
 
 inline sal_Bool SfxDispatcher::IsActive( const SfxShell& rShell )
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Mit dieser Methode kann abgefragt werden, ob sich eine bestimmte
-    <SfxShell>-Instanz auf dem SfxDispatcher befindet.
+    This method checks whether a particular <SfxShell> instance is 
+    on the SfxDispatcher.
 
-    [R"uckgabewert]
+    [Return value]
 
     sal_Bool				sal_True
-                        Die SfxShell-Instanz befindet sich auf dem
-                        SfxDispatcher.
+                        The SfxShell instance is on the SfxDispatcher.
 
                         sal_False
-                        Die SfxShell-Instanz befindet sich nicht auf dem
-                        SfxDispatcher.
-
+                        The SfxShell instance is not on the SfxDispatcher.
 */
 
 {
@@ -335,21 +331,20 @@ inline sal_Bool SfxDispatcher::IsActive( const SfxShell& rShell )
 
 inline sal_Bool SfxDispatcher::IsOnTop( const SfxShell& rShell )
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Mit dieser Methode kann abgefragt werden, ob sich eine bestimmte
-    <SfxShell>-Instanz zuoberst auf dem SfxDispatcher befindet.
+    This method checks whether a particular <SfxShell> instance is on 
+    top of the SfxDispatcher.
 
-    [R"uckgabewert]
+    [Return value]
 
     sal_Bool				sal_True
-                        Die SfxShell-Instanz befindet sich als oberste
-                        SfxShell auf dem SfxDispatcher.
+                        The SfxShell instance is on the top of 
+                        the SfxDispatcher.
 
                         sal_False
-                        Die SfxShell-Instanz befindet sich nicht als
-                        oberste SfxShell auf dem SfxDispatcher.
-
+                        The SfxShell instance is not on the top of 
+                        the SfxDispatcher.
 */
 
 {
diff --git a/sfx2/inc/sfx2/docfac.hxx b/sfx2/inc/sfx2/docfac.hxx
index 2426843..8f5cf0b 100644
--- a/sfx2/inc/sfx2/docfac.hxx
+++ b/sfx2/inc/sfx2/docfac.hxx
@@ -54,25 +54,25 @@ class SfxBindings;
 typedef void (*SfxVoidFunc)();
 
 #define SDT_SDT_DOCFACTPRIO     10      // Explorer
-#define SDT_SW_DOCFACTPRIO      20      // Text-Dokument
-#define SDT_SWW_DOCFACTPRIO     21    	// Web-Dokument
-#define SDT_SC_DOCFACTPRIO      30      // Tabellen-Dokument
-#define SDT_SI_DOCFACTPRIO      40      // Impress-Dokument
-#define SDT_SD_DOCFACTPRIO      41      // Draw-Dokument
-#define SDT_SCH_DOCFACTPRIO     50      // Chart-Dokument
-#define SDT_SMA_DOCFACTPRIO     60      // Math-Dokument
-#define SDT_SIM_DOCFACTPRIO     70      // Image-Dokument
-#define SDT_FRM_DOCFACTPRIO    100      // Rahmen-Dokument
-#define SDT_MSG_DOCFACTPRIO    110      // Nachrichten-Dokument
-#define SDT_SDB_DOCFACTPRIO    200      // Datenbank-Dokument
+#define SDT_SW_DOCFACTPRIO      20      // Text Document
+#define SDT_SWW_DOCFACTPRIO     21      // Web Document
+#define SDT_SC_DOCFACTPRIO      30      // Table Document
+#define SDT_SI_DOCFACTPRIO      40      // Impress Document
+#define SDT_SD_DOCFACTPRIO      41      // Draw Document
+#define SDT_SCH_DOCFACTPRIO     50      // Chart Document
+#define SDT_SMA_DOCFACTPRIO     60      // Math Document
+#define SDT_SIM_DOCFACTPRIO     70      // Image Document
+#define SDT_FRM_DOCFACTPRIO    100      // Frame Document
+#define SDT_MSG_DOCFACTPRIO    110      // Message Document
+#define SDT_SDB_DOCFACTPRIO    200      // Database Document
 
 //====================================================================
 
 class SFX2_DLLPUBLIC SfxObjectFactory
 {
 private:
-    const char* 			pShortName;		// Objekt-Kurzname
-    SfxObjectFactory_Impl*	pImpl;			// Zusatzdaten
+    const char*             pShortName; 
+    SfxObjectFactory_Impl*  pImpl;      // Additional Data
     SfxObjectShellFlags     nFlags;
     SAL_DLLPRIVATE void Construct();
 
diff --git a/sfx2/inc/sfx2/doctempl.hxx b/sfx2/inc/sfx2/doctempl.hxx
index 56cadd0..fdf4010 100644
--- a/sfx2/inc/sfx2/doctempl.hxx
+++ b/sfx2/inc/sfx2/doctempl.hxx
@@ -87,16 +87,15 @@ public:
 
     String				GetDefaultTemplatePath(const String &rLongName);
 
-    // Pfad zur Vorlage geben lassen; logischer Name muss angegeben
-    // werden, damit beim Ueberschreiben einer Vorlage der
-    // richtige Dateiname gefunden werden kann
+    // Path to the template; the logical name must be given in order to find 
+    // the correct file name when overwriting a template
     String				GetTemplatePath(sal_uInt16 nRegion, const String &rLongName) const;
 
     // Allows to retrieve the target template URL from the UCB
     ::rtl::OUString		GetTemplateTargetURLFromComponent( const ::rtl::OUString& aGroupName,
                                                          const ::rtl::OUString& aTitle );
 
-    // Speichern als Vorlage hat geklappt -> Aktualisieren
+    // Save as template worked -> update
     void			NewTemplate(sal_uInt16 nRegion,
                                 const String &rLongName,
                                 const String &rFileName);
diff --git a/sfx2/inc/sfx2/filedlghelper.hxx b/sfx2/inc/sfx2/filedlghelper.hxx
index 7155006..4f9d38c 100644
--- a/sfx2/inc/sfx2/filedlghelper.hxx
+++ b/sfx2/inc/sfx2/filedlghelper.hxx
@@ -84,10 +84,10 @@ class Window;
 #define SFXWB_READONLY			WB_READONLY                 // ((WinBits)0x02000000)
 #define SFXWB_PATHDIALOG		WB_PATH                     // ((WinBits)0x00100000)
 #define SFXWB_CLASSPATH			( 0x08000000L | SFXWB_PATHDIALOG )
-#define SFXWB_SHOWALLFOLDER		0x10000000L		// alle Ordner auch Mail/News/...
-#define SFXWB_MULTISELECTION	0x20000000L		// Multiselection an
+#define SFXWB_SHOWALLFOLDER		0x10000000L		// All folders also mail/news/...
+#define SFXWB_MULTISELECTION	0x20000000L
 #define SFXWB_NOREMOTE          0x40000000L
-#define SFXWB_SHOWVERSIONS		0x80000000L  	// Versionsauswahl anzeigen
+#define SFXWB_SHOWVERSIONS		0x80000000L
 
 #define SFXWB_GRAPHIC           0x00800000L     // FileOpen with link and preview box
 #define SFXWB_SHOWSTYLES        0x01000000L     // FileOpen with link and preview box and styles
diff --git a/sfx2/inc/sfx2/frame.hxx b/sfx2/inc/sfx2/frame.hxx
index a042085..c62690b 100644
--- a/sfx2/inc/sfx2/frame.hxx
+++ b/sfx2/inc/sfx2/frame.hxx
@@ -99,16 +99,15 @@ typedef ::std::vector< String* > TargetList;
 #define SFXFRAME_HASTITLE     0x0001
 
 //==========================================================================
-// Ein SfxFrame ist eine Verwaltungsklasse f"ur Fenster und deren Inhalte.
-// Eine SfxApplication pr"asentiert sich als Hierarchie von SfxFrames, wobei
-// die konkreten Inhalte in den abgeleiteten Klassen festgelegt werden.
-// Die Basisklasse SfxFrame implementiert 2 Aspekte der Frames: Benennung und
-// Kontrolle der Lebensdauer.
-// Innerhalb einer Frames-Hierarchie kontrolliert immer der ParentFrame die
-// Lebensdauer seiner ChildFrames, auch wenn sie in der Regel gar nicht von
-// ihm selbst erzeugt wurden. Durch Aufruf vonn DoClose() an irgendeinem
-// Frame in der Hierarchie kann ein Teil des "Frameworks" entfernt werden,
-// wobei sich Frames an ihren ParentFrames selbst abmelden.
+// SfxFrame is a management class for windows and their content. 
+// A SfxApplication represent a hierarchy of SfxFrames, with which the actual 
+// content in the derived classes is defined. The base class SfxFrame 
+// implements two aspects of frames: naming and control of its lifespan.  
+// Inside a frame hierarchy the parent frame always controls the lifespan of 
+// its child frames, even though they usually are not even produced by the 
+// parent. By calling DoCloser() on any frame in the hierarchy, 
+// a part of the "framework" can be removed, where frames unsubscribe 
+// from their parent frames.
 //==========================================================================
 
 class SfxFrameArr_Impl;
@@ -195,7 +194,7 @@ public:
     SAL_DLLPRIVATE sal_Bool IsClosing_Impl() const;
     SAL_DLLPRIVATE void SetIsClosing_Impl();
 
-                        // Methoden f"ur den Zugriff auf das aktuelle Set
+    // Methods for accessing the current set
     SAL_DLLPRIVATE void SetDescriptor( SfxFrameDescriptor* );
     SAL_DLLPRIVATE SfxFrameDescriptor* GetDescriptor() const;
 
diff --git a/sfx2/inc/sfx2/frmdescr.hxx b/sfx2/inc/sfx2/frmdescr.hxx
index ef53954..369226c 100644
--- a/sfx2/inc/sfx2/frmdescr.hxx
+++ b/sfx2/inc/sfx2/frmdescr.hxx
@@ -47,16 +47,14 @@ typedef SfxFrameDescriptor* SfxFrameDescriptorPtr;
 SV_DECL_PTRARR(SfxFramesArr, SfxFrameDescriptorPtr, 4, 2)
 
 //===========================================================================
-// Die SfxFrame...descriptoren bauen eine rekursive Struktur auf, die
-// s"amtliche zur Anzeige des Frame-Dokuments erforderlichen Daten umfa\st.
-// "Uber einen SfxFrameSetDescriptor hat man Zugriff auf die gesamte darunter
-// liegende Struktur.
-// Aufgrund der besonderen Eigenschaften des SfxFrames-Dokuments ist ein
-// SfxFramesSetDescriptor nicht nur der Inhalt dieses Dokuments, sondern
-// beschreibt auch die View darauf.
-// Das FrameSet wird aus Zeilen aufgebaut, die wiederum die eigentlichen
-// Fenster enthalten. Eine Zeile kann horizontal oder vertikal ausgerichtet
-// sein, woraus sich auch das Alignment des FrameSets ergibt.
+// The SfxFrame descriptors build a recursive structure, that covers all the 
+// required data in-order to display the frame document. 
+// Through a SfxFrameSetDescriptor access is given to the whole underlying 
+// structure. Due to the nature of the SfxFrames document, the 
+// SfxFramesSetDescriptor is not only the content of this document, but also 
+// describes the view on it. The FrameSet is made up of lines, which in turn, 
+// contains the actual window . A line can be horizontally or vertically 
+// aligned, from which also the alignment of the FrameSet is given.
 //===========================================================================
 
 enum ScrollingMode
@@ -105,7 +103,7 @@ public:
                             SfxFrameDescriptor();
                             ~SfxFrameDescriptor();
 
-                            // Eigenschaften
+                            // Properties
     void					TakeProperties( const SfxFrameProperties& rProp );
 
                             // FileName/URL
@@ -184,7 +182,7 @@ public:
     void					SetHasUI( sal_Bool bOn )
                             { bHasUI = bOn; }
 
-                            // Attribute f"ur das Splitwindow
+                            // Attribute for Splitwindow
     sal_uInt16					GetItemId() const
                             { return nItemId; }
     void					SetItemId( sal_uInt16 nId )
@@ -193,11 +191,11 @@ public:
     long					GetSize() const;
     sal_uInt16					GetItemPos() const;
 
-                            // Kopie z.B. f"ur die Views
+                            // Copy for example for Views
     SfxFrameDescriptor*     Clone( sal_Bool bWithIds = sal_True ) const;
 };
 
-// Kein Bock, einen operator= zu implementieren...
+// No block to implement a =operator 
 struct SfxFrameProperties
 {
     String								aURL;
diff --git a/sfx2/inc/sfx2/frmhtml.hxx b/sfx2/inc/sfx2/frmhtml.hxx
index 016a83b..10e744d 100644
--- a/sfx2/inc/sfx2/frmhtml.hxx
+++ b/sfx2/inc/sfx2/frmhtml.hxx
@@ -51,7 +51,7 @@ protected:
    SfxHTMLParser( rStream, bIsNewDoc, pMediumPtr ) {};
 
 public:
-    // Diese Methoden koennen auch von anderen Parsern benutzt werden
+    // These methods can also be used by other parsers.
     static void             ParseFrameOptions(SfxFrameDescriptor*, const HTMLOptions*, const String& );
 
 };
diff --git a/sfx2/inc/sfx2/hintpost.hxx b/sfx2/inc/sfx2/hintpost.hxx
index bd7a7a3..6c1968a 100644
--- a/sfx2/inc/sfx2/hintpost.hxx
+++ b/sfx2/inc/sfx2/hintpost.hxx
@@ -39,17 +39,16 @@ class SfxHint;
 
 class SfxHintPoster: public SvRefBase
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Mit Instanzen dieser Klasse k"onnen eindeutige Events per PostUserEvent
-    "uber die StarView-Application verschickt werden. Wenn das User-Event
-    ausgel"ost wird, wird der Handler <Event()> gerufen, dessen
-    Basisimplementierung den mit <SetEventHdl()> angegbenen Link ruft.
+    With instances of this class unique events per PostUserEvent can be sent 
+    using the StarView-application. If the User-Event is triggered often, 
+    the handler <Event()> is called, the base implementation with the 
+    <SetEventHdl()> line is making these link calls. 
 
-    Die Instanz wird via Ref-Count mindestens solange gehalten, wie
-    ein ggf. abgeschicktes Event noch nicht angekommen ist. Sollte das
-    Ziel vorher sterben, ist die Verbindung zuvor mit 'SetEventHdl(GenLink())'
-    zu kappen.
+    The instance are held via Ref-Count at least as long as a possible sent
+    event has not arrived yet. Should be killed before the goal, before the 
+    connection is SetEventHdl (GenLink ()) .
 */
 
 {
diff --git a/sfx2/inc/sfx2/htmlmode.hxx b/sfx2/inc/sfx2/htmlmode.hxx
index e841ad9..7979b6a 100644
--- a/sfx2/inc/sfx2/htmlmode.hxx
+++ b/sfx2/inc/sfx2/htmlmode.hxx
@@ -30,19 +30,19 @@
 
 
 #define HTMLMODE_ON         		0x0001
-#define HTMLMODE_PARA_BORDER		0x0002 /* Absatzumrandungen */
-#define HTMLMODE_PARA_DISTANCE      0x0004 /* bestimmte Absatzabstaende */
-#define HTMLMODE_SMALL_CAPS         0x0008 /* Kapitaelchen */
-#define HTMLMODE_FRM_COLUMNS        0x0010 /* spaltige Rahmen */
+#define HTMLMODE_PARA_BORDER        0x0002 
+#define HTMLMODE_PARA_DISTANCE      0x0004 
+#define HTMLMODE_SMALL_CAPS         0x0008 
+#define HTMLMODE_FRM_COLUMNS        0x0010 
 #define HTMLMODE_SOME_STYLES 	    0x0020 /* mind. MS IE */
 #define HTMLMODE_FULL_STYLES 	    0x0040 /* == SW */
-#define HTMLMODE_BLINK          	0x0080 /* blinkende Zeichen*/
-#define HTMLMODE_PARA_BLOCK         0x0100 /* Blocksatz */
-#define HTMLMODE_DROPCAPS          	0x0200 /* Initialen*/
-#define HTMLMODE_FIRSTLINE          0x0400 /* Erstzeileneinzug mit Spacer == NS 3.0 */
-#define HTMLMODE_GRAPH_POS          0x0800 /* Grafikpositionen Hintergrund */
-#define HTMLMODE_FULL_ABS_POS       0x1000 /* abs. Rahmenpositionierung */
-#define HTMLMODE_SOME_ABS_POS       0x2000 /* abs. Rahmenpositionierung vollst.*/
+#define HTMLMODE_BLINK              0x0080 
+#define HTMLMODE_PARA_BLOCK         0x0100 
+#define HTMLMODE_DROPCAPS           0x0200 
+#define HTMLMODE_FIRSTLINE          0x0400 /* First-line intent with Spacer == NS 3.0 */
+#define HTMLMODE_GRAPH_POS          0x0800 
+#define HTMLMODE_FULL_ABS_POS       0x1000 
+#define HTMLMODE_SOME_ABS_POS       0x2000 
 #define HTMLMODE_RESERVED1          0x4000
 #define HTMLMODE_RESERVED0          0x8000
 
diff --git a/sfx2/inc/sfx2/linkmgr.hxx b/sfx2/inc/sfx2/linkmgr.hxx
index 95f10d4..0ea1494 100644
--- a/sfx2/inc/sfx2/linkmgr.hxx
+++ b/sfx2/inc/sfx2/linkmgr.hxx
@@ -48,10 +48,10 @@ namespace com { namespace sun { namespace star {
 
 namespace sfx2
 {
-    // Damit der Link ueber den Status der zu ladenen Grafik informierten werden
-    // verschickt das FileObject ein SvData, mit der FormatId
-    // "RegisterStatusInfoId" und ein einem String als Datentraeger. Dieser
-    // enthaelt den folgenden enum.
+    // For the link to receive information about the status of graphics that 
+    // will be loaded the FileObject sends a SvData, which contains the 
+    // FormatID "RegisterStatusInfoId" and a string as the data container. 
+    // This contains the following enum.
 
 class SvBaseLink;
 class SvBaseLinkRef;
@@ -71,7 +71,7 @@ class SFX2_DLLPUBLIC LinkManager
     SvBaseLinks		aLinkTbl;
     SvLinkSources aServerTbl;
 
-    SfxObjectShell *pPersist; // LinkMgr muss vor SfxObjectShell freigegeben werden
+    SfxObjectShell *pPersist; // LinkMgr must be release before SfxObjectShell
 protected:
     sal_Bool 		InsertLink( SvBaseLink* pLink, sal_uInt16 nObjType, sal_uInt16 nUpdateType,
                             const String* pName = 0 );
@@ -104,23 +104,23 @@ public:
     void		Remove( sal_uInt16 nPos, sal_uInt16 nCnt = 1 );
     sal_Bool		Insert( SvBaseLink* pLink );
 
-                // den Link mit einem SvLinkSource verbinden und in die Liste eintragen
+    // the links connect to a SvLinkSource and adds to the list
     sal_Bool 		InsertDDELink( SvBaseLink*,
                         const String& rServer,
                         const String& rTopic,
                         const String& rItem );
 
-                // falls am Link schon alles eingestellt ist !
+    // if everything is already set at the link!
     sal_Bool 		InsertDDELink( SvBaseLink* );
 
-    // den Link mit einem PseudoObject verbinden und in die Liste eintragen
+    // Connect the links to a pseudo-object and add to the list
     sal_Bool InsertFileLink( sfx2::SvBaseLink&,
                         sal_uInt16 nFileType,
                         const String& rTxt,
                         const String* pFilterNm = 0,
                         const String* pRange = 0 );
 
-            // falls am Link schon alles eingestellt ist !
+    // if everything is already set for the link!
     sal_Bool InsertFileLink( sfx2::SvBaseLink& );
 
     void ReconnectDdeLink(SfxObjectShell& rServer);
@@ -134,7 +134,7 @@ public:
      */
     void LinkServerShell(const ::rtl::OUString& rPath, SfxObjectShell& rServer, ::sfx2::SvBaseLink& rLink) const;
 
-                // erfrage die Strings fuer den Dialog
+    // Obtain the string for the dialog
     sal_Bool GetDisplayNames( const SvBaseLink *,
                                     String* pType,
                                     String* pFile = 0,
@@ -148,29 +148,29 @@ public:
                                 sal_Bool bUpdateGrfLinks = sal_False,
                                 Window* pParentWin = 0 );
 
-                // Liste aller Links erfragen (z.B. fuer Verknuepfungs-Dialog)
+    // Call for list of links (eg for link-dialog)
     const 		SvBaseLinks& GetLinks() const { return aLinkTbl; }
 
-    // ----------------- Serverseitige Verwaltung --------------------
+    // ----------------- Server-side management --------------------
 
-                // Liste der zu serviereden Links erfragen
+    // Call with list of links to server
     const SvLinkSources& GetServers() const { return aServerTbl; }
-                // einen zu servierenden Link eintragen/loeschen
+    // Link register/delete
     sal_Bool 		InsertServer( SvLinkSource* rObj );
     void 		RemoveServer( SvLinkSource* rObj );
     void 		RemoveServer( sal_uInt16 nPos, sal_uInt16 nCnt = 1 )
                 {	aServerTbl.Remove( nPos, nCnt ); }
 
-    // eine Uebertragung wird abgebrochen, also alle DownloadMedien canceln
-    // (ist zur Zeit nur fuer die FileLinks interressant!)
+    // A transfer is aborted, so cancel all download media 
+    // (for the time beeing this is only of interest for the FileLinks!)
     void CancelTransfers();
 
-    // um Status Informationen aus dem FileObject an den BaseLink zu
-    // senden, gibt es eine eigene ClipBoardId. Das SvData-Object hat
-    // dann die entsprechenden Informationen als String.
-    // Wird zur Zeit fuer FileObject in Verbindung mit JavaScript benoetigt
-    // - das braucht Informationen ueber Load/Abort/Error
-    static sal_uIntPtr  RegisterStatusInfoId();
+    // To send status information from the FileObject to the Baselink, 
+    // for this there exist a separate ClipBoardId. The SvData-object has 
+    // got the appropriate information as a string.
+    // Is now required for FileObject in conjunction with JavaScript  
+    // this needs information about Load/Abort/Error
+    static ULONG  RegisterStatusInfoId();
 
     // if the mimetype says graphic/bitmap/gdimetafile then get the
     // graphic from the Any. Return says no errors
@@ -183,15 +183,15 @@ private:
                 LinkManager& operator=( const LinkManager& );
 };
 
-// Trenner im LinkName fuer die DDE-/File-/Grafik- Links
-// (nur wer es braucht, um einen SvLinkName zusammenzubasteln)
+// Separator in the link name for the DDE-/File-/Graphics- links
+// (only those who need to construct a SvLinkName)
 const sal_Unicode cTokenSeperator = 0xFFFF;
 
-// erzeuge einen String fuer den SvLinkName. Fuer
-// - DDE die ersten 3 Strings, (Server, Topic, Item)
-// - File-/Grf-LinkNms die letzen 3 Strings (FileName, Bereich, Filter)
+// create a string for the SvLinkName. For:
+// - DDE the first 3 Strings, (Server, Topic, Item)
+// - File-/Graphics-LinkNames the last 3 Strings (FileName, Region, Filter)
 SFX2_DLLPUBLIC void MakeLnkName( String& rName,
-                 const String* pType,		// kann auch 0 sein !!
+                 const String* pType,       // Can also be null!!
                  const String& rFile,
                  const String& rLink,
                  const String* pFilter = 0 );
diff --git a/sfx2/inc/sfx2/linksrc.hxx b/sfx2/inc/sfx2/linksrc.hxx
index 999d9d7..5748668 100644
--- a/sfx2/inc/sfx2/linksrc.hxx
+++ b/sfx2/inc/sfx2/linksrc.hxx
@@ -48,7 +48,7 @@ class Window;
 class String;
 
 #ifndef ADVISEMODE_NODATA
-// Muessen die gleichen Werte wie Ole2 ADVF_* sein
+// Must be the same value as Ole2 ADVF_*
 #define ADVISEMODE_NODATA       0x01
 //#define ADVISEMODE_PRIMEFIRST   0x02
 #define ADVISEMODE_ONLYONCE     0x04
diff --git a/sfx2/inc/sfx2/lnkbase.hxx b/sfx2/inc/sfx2/lnkbase.hxx
index 45b3f9a..ddb946a 100644
--- a/sfx2/inc/sfx2/lnkbase.hxx
+++ b/sfx2/inc/sfx2/lnkbase.hxx
@@ -54,16 +54,16 @@ class FileDialogHelper;
 #define	OBJECT_DDE_EXTERN	0x02
 #endif
 
-#define	OBJECT_CLIENT_SO			0x80 // ein Link
+#define OBJECT_CLIENT_SO              0x80 // a Link
 #define	OBJECT_CLIENT_DDE			0x81
-//#define	OBJECT_CLIENT_OLE			0x82 // ein Ole-Link
-//#define	OBJECT_CLIENT_OLE_CACHE  	0x83 // ein Ole-Link mit SvEmbeddedObject
+//#define   OBJECT_CLIENT_OLE         0x82 // a Ole-Link
+//#define   OBJECT_CLIENT_OLE_CACHE   0x83 // a Ole-Link with SvEmbeddedObject
 #define	OBJECT_CLIENT_FILE			0x90
 #define	OBJECT_CLIENT_GRF			0x91
 #define	OBJECT_CLIENT_OLE			0x92 // embedded link
 
 enum sfxlink {
-    // Ole2 compatibel und persistent
+    // Ole2 compatibel and persistent
     LINKUPDATE_ALWAYS = 1,
     LINKUPDATE_ONCALL = 3,
 
@@ -84,7 +84,7 @@ private:
     sal_uInt16 					nObjType;
     sal_Bool					bVisible : 1;
     sal_Bool					bSynchron : 1;
-    sal_Bool					bUseCache : 1;		// fuer GrafikLinks!
+    sal_Bool					bUseCache : 1;	// for Graphics Links!
     sal_Bool                    bWasLastEditOK : 1;
 
     DECL_LINK( EndEditHdl, String* );
@@ -94,9 +94,9 @@ private:
 protected:
     void			SetObjType( sal_uInt16 );
 
-                    // setzen des LinkSourceName ohne aktion
+    // Set LinkSourceName without action
     void			SetName( const String & rLn );
-                    // LinkSourceName der im SvLinkBase steht
+    // LinkSourceName which is in SvLinkBase
     String		 	GetName() const;
 
     ImplBaseLinkData* pImplData;
@@ -120,7 +120,7 @@ protected:
 
 public:
                     TYPEINFO();
-                    // ask JP
+
     virtual void    Closed();
                     SvBaseLink( const String& rNm, sal_uInt16 nObjectType,
                                  SvLinkSource* );
@@ -151,10 +151,10 @@ public:
     // Link impl: DECL_LINK( MyEndDialogHdl, SvBaseLink* ); <= param is this
     virtual void    Edit( Window*, const Link& rEndEditHdl );
 
-        // soll der Link im Dialog angezeigt werden ? (Links im Link im ...)
+    // should the link appear in the dialog? (to the left in the link in the...)
     sal_Bool 	        IsVisible() const   		{ return bVisible; }
     void 	        SetVisible( sal_Bool bFlag )	{ bVisible = bFlag; }
-        // soll der Link synchron oder asynchron geladen werden?
+    // should the Link be loaded synchronous or asynchronous?
     sal_Bool 	        IsSynchron() const   		{ return bSynchron; }
     void 	        SetSynchron( sal_Bool bFlag )	{ bSynchron = bFlag; }
 
diff --git a/sfx2/inc/sfx2/mgetempl.hxx b/sfx2/inc/sfx2/mgetempl.hxx
index 4a0a6e4..8e9872a 100644
--- a/sfx2/inc/sfx2/mgetempl.hxx
+++ b/sfx2/inc/sfx2/mgetempl.hxx
@@ -39,9 +39,9 @@
 #include <svtools/svmedit2.hxx>
 #include <svtools/svmedit.hxx>
 
-/* erwartet:
-    SID_TEMPLATE_NAME   : 	In: StringItem, Name der Vorlage
-    SID_TEMPLATE_FAMILY :	In: Familie der Vorlage
+/* expected:
+    SID_TEMPLATE_NAME   :   In: StringItem, Name of Template
+    SID_TEMPLATE_FAMILY :   In: Family of Template
 */
 
 class SfxStyleFamilies;
@@ -79,7 +79,7 @@ class SfxManageStyleSheetPage : public SfxTabPage
     String aBuf;
     sal_Bool bModified;
 
-        // initiale Daten des Styles
+    // initial data for the style
     String aName;
     String aFollow;
     String aParent;
diff --git a/sfx2/inc/sfx2/minarray.hxx b/sfx2/inc/sfx2/minarray.hxx
index 8344363..e3acd69 100644
--- a/sfx2/inc/sfx2/minarray.hxx
+++ b/sfx2/inc/sfx2/minarray.hxx
@@ -282,7 +282,7 @@ void ARR::Insert( sal_uInt16 nPos, const T& rElems, sal_uInt16 nLen ) \
     if ( nUnused == 0 ) \
     { \
         \
-        /* auf die naechste Grow-Grenze aufgerundet vergroeszern */ \
+        /* increase (round up) to the next Grow-limit  */       \
         sal_uInt16 nNewSize; \
         for ( nNewSize = nUsed+nGrow; nNewSize < (nUsed + nLen); ++nNewSize ) \
             /* empty loop */; \
diff --git a/sfx2/inc/sfx2/mnumgr.hxx b/sfx2/inc/sfx2/mnumgr.hxx
index f5f421e..80da069 100644
--- a/sfx2/inc/sfx2/mnumgr.hxx
+++ b/sfx2/inc/sfx2/mnumgr.hxx
@@ -57,9 +57,9 @@ class SfxMenuManager
 {
 friend class SfxPopupMenuManager;
 
-    SfxVirtualMenu* 		pMenu;			// das eigentliche Menu
+    SfxVirtualMenu*  pMenu;     // the actual Menu
     SfxVirtualMenu* 		pOldMenu;		// only while reconfiguring
-    sal_Bool					bMenuBar;		// Popup oder MenuBar
+    sal_Bool         bMenuBar;  // Popup or MenuBar
     SfxBindings*			pBindings;
     ResMgr* 				pResMgr;
     sal_uInt32              nType;
diff --git a/sfx2/inc/sfx2/msg.hxx b/sfx2/inc/sfx2/msg.hxx
index 6cee037..2fd17ca 100644
--- a/sfx2/inc/sfx2/msg.hxx
+++ b/sfx2/inc/sfx2/msg.hxx
@@ -36,42 +36,51 @@
 
 //--------------------------------------------------------------------
 
-#define SFX_SLOT_CACHABLE		   0x0001L // exklusiv zu VOLATILE, default
-#define SFX_SLOT_VOLATILE		   0x0002L // per Timer alle 2s neu geholt, exklusiv zu CACHABLE
-#define SFX_SLOT_TOGGLE 		   0x0004L // invertiert bei Execute alten Wert
-#define SFX_SLOT_AUTOUPDATE 	   0x0008L // invalidiert den Status nach Execute automatisch
-
-#define SFX_SLOT_SYNCHRON		   0x0010L // exklusiv zu ASYNCHRON, default
-#define SFX_SLOT_ASYNCHRON		   0x0020L // via Post-Message, exklusiv zu SYNCHRON
-
-#define SFX_SLOT_HASCOREID		   0x0040L // Slot-ID/Which-ID Mappting durchf"uhren
-#define SFX_SLOT_HASDIALOG		   0x0080L // Punkte fuer Dialog nach recofig
-
-#define SFX_SLOT_NORECORD		   0x0100L // kein Recording
-#define SFX_SLOT_RECORDPERITEM	   0x0200L // je Item ein Statement
-#define SFX_SLOT_RECORDPERSET	   0x0400L // das ganze Set ist ein Statement, def.
-#define SFX_SLOT_RECORDMANUAL	   0x0800L // Recording vom Applikationsentwickler                                         iss-default
-
-#define SFX_SLOT_RECORDABSOLUTE 0x1000000L // Recording mit absolutem Target
+#define SFX_SLOT_CACHABLE      0x0001L // exclusiv to VOLATILE, default
+#define SFX_SLOT_VOLATILE      0x0002L // per Timer every 2s get new, 
+                                       // exclusiv to CACHABLE
+#define SFX_SLOT_TOGGLE        0x0004L // inverted for Execute old value
+#define SFX_SLOT_AUTOUPDATE    0x0008L // invalidated the status automatically 
+                                       // after execute
+
+#define SFX_SLOT_SYNCHRON      0x0010L // exclusiv to ASYNCHRON, default
+#define SFX_SLOT_ASYNCHRON     0x0020L // via Post-Message, exclusiv 
+                                       // to SYNCHRON
+
+#define SFX_SLOT_HASCOREID     0x0040L // Slot-ID/Which-ID execute mapping
+#define SFX_SLOT_HASDIALOG     0x0080L // Coordinates for dialogue after recofig
+
+#define SFX_SLOT_NORECORD      0x0100L // no recording
+#define SFX_SLOT_RECORDPERITEM 0x0200L // each item, one statement
+#define SFX_SLOT_RECORDPERSET  0x0400L // The whole Set is a Statement, default
+#define SFX_SLOT_RECORDMANUAL  0x0800L // Recording by the application 
+                                       // developer is default
+
+#define SFX_SLOT_RECORDABSOLUTE 0x1000000L // Recording with absolute Target
 #define SFX_SLOT_STANDARD		( SFX_SLOT_CACHABLE | \
                                   SFX_SLOT_SYNCHRON | \
                                   SFX_SLOT_RECORDPERSET )
 
-#define SFX_SLOT_PROPGET		  0x1000L  // abfragbares Property
-#define SFX_SLOT_PROPSET		  0x2000L  // setzbares Property, exklusiv zu SFX_SLOT_METHOD
-#define SFX_SLOT_METHOD 		  0x4000L  // Methode, exklusiv zu SFX_SLOT_PROPSET
+#define SFX_SLOT_PROPGET       0x1000L  // get property
+#define SFX_SLOT_PROPSET       0x2000L  // set property, exclusiv to 
+                                        // SFX_SLOT_METHOD
+#define SFX_SLOT_METHOD        0x4000L  // Method, exclusiv to SFX_SLOT_PROPSET
 
-#define SFX_SLOT_FASTCALL		  0x8000L  // vor Execute keine Pr"ufung, ob disabled
+#define SFX_SLOT_FASTCALL      0x8000L  // No test if disabled before Execute
 
-#define SFX_SLOT_STATUSBARCONFIG 0x10000L  // konfigurierbar in Statuszeile
-#define SFX_SLOT_MENUCONFIG 	 0x20000L  // konfigurierbar im Men"u
-#define SFX_SLOT_TOOLBOXCONFIG	 0x40000L  // konfigurierbar in Toolboxen
-#define SFX_SLOT_ACCELCONFIG	 0x80000L  // konfigurierbar auf Tasten
+#define SFX_SLOT_STATUSBARCONFIG 0x10000L  // configurable status row
+#define SFX_SLOT_MENUCONFIG      0x20000L  // configurable Menu
+#define SFX_SLOT_TOOLBOXCONFIG   0x40000L  // configurable Toolboxen
+#define SFX_SLOT_ACCELCONFIG     0x80000L  // configurable keys
 
-#define SFX_SLOT_CONTAINER		0x100000L  // beim InPlace vom Container bedient
-#define SFX_SLOT_READONLYDOC	0x200000L  // auch bei readonly-Docs verf"ugbar
-#define SFX_SLOT_IMAGEROTATION  0x400000L  // bei Vertical/Bidi writing Image drehen
-#define SFX_SLOT_IMAGEREFLECTION  0x800000L  // bei Vertical/Bidi writing Image spiegeln
+#define SFX_SLOT_CONTAINER      0x100000L  // Operated by the container at 
+                                           // InPlace
+#define SFX_SLOT_READONLYDOC    0x200000L  // also available for 
+                                           // read-only Documents
+#define SFX_SLOT_IMAGEROTATION  0x400000L  // Rotate image on Vertical/
+                                           // Bi-directional writing 
+#define SFX_SLOT_IMAGEREFLECTION  0x800000L // Mirror image on Vertical/
+                                           // Bi-directional writing 
 
 //--------------------------------------------------------------------
 
@@ -239,9 +248,9 @@ class SfxPoolItem;
 
 struct SfxFormalArgument
 {
-    const SfxType*			pType;	// Typ des Parameters (SfxPoolItem Subklasse)
-    const char*	pName;	// Name des Parameters
-    sal_uInt16      			nSlotId;// Slot-Id zur Identifikation des Parameters
+    const SfxType*  pType;    // Type of the parameter (SfxPoolItem subclass)
+    const char*     pName;    // Name of the sParameters
+    sal_uInt16      nSlotId;  // Slot-Id for identification of the Parameters
 
     const TypeId&			Type() const
                             { return pType->aTypeId; }
@@ -254,29 +263,30 @@ struct SfxFormalArgument
 class SfxSlot
 {
 public:
-    sal_uInt16						nSlotId;		// in Shell eindeutige Slot-Id
-    sal_uInt16						nGroupId;		// f"ur Konfigurations-Bereich
-    sal_uIntPtr						nHelpId;		// i.d.R. == nSlotId
-    sal_uIntPtr						nFlags;			// artihm. veroderte Flags
+    sal_uInt16	  nSlotId;   // Unique slot-ID in Shell
+    sal_uInt16	  nGroupId;  // for configuration region
+    sal_uIntPtr	  nHelpId;   // Usually == nSlotId
+    sal_uIntPtr	  nFlags;    // artihmetic ordered Flags
 
-    sal_uInt16						nMasterSlotId;	// Enum-Slot bzw. Which-Id
-    sal_uInt16						nValue;			// Wert, falls Enum-Slot
+    sal_uInt16	  nMasterSlotId;  // Enum-Slot for example Which-Id
+    sal_uInt16	  nValue;         // Value, in case of Enum-Slot
 
-    SfxExecFunc			        fnExec;			// Funktion zum Ausf"uhren
-    SfxStateFunc		        fnState;		// Funktion f"ur Status
+    SfxExecFunc   fnExec;   // Function to be excecuted
+    SfxStateFunc  fnState;  // Function for Status
 
-    const SfxType*				pType;			// SfxPoolItem-Typ (Status)
-    const char*		pName;			// Name des Slots
-    const char*		pMethodName;	// Name der Method falls anders
+    const SfxType*  pType;        // SfxPoolItem-Type (Status)
+    const char*     pName;        // Name of the Slots
+    const char*     pMethodName;  // Name of the Method if different
 
-    const SfxSlot*				pLinkedSlot;	// Master-Slot f"ur Enum-Werte
-    const SfxSlot*				pNextSlot;		// mit derselben Status-Methode
+    const SfxSlot*  pLinkedSlot; // Master-Slot for Enum value
+    const SfxSlot*  pNextSlot;   // with the same Status-Method
 
-    const SfxFormalArgument*	pFirstArgDef;	// erste formale Argument-Definition
-    sal_uInt16						nArgDefCount;	// Anzahl der formalen Argumente
-    long						nDisableFlags;		// DisableFlags, die vorhanden sein
-                                                // m"ussen, damit der Slot enabled ist
-    const char*		pUnoName;		// UnoName des Slots
+    const SfxFormalArgument*  pFirstArgDef;  // first formal Argument-Definition
+    sal_uInt16                nArgDefCount;  // Number of formal Argumentents
+    long                      nDisableFlags; // DisableFlags that need to be 
+                                             // present, so that the Slot 
+                                             // can be enabled
+    const char*     pUnoName;      // UnoName for the Slots
 
 public:
 
@@ -291,8 +301,6 @@ public:
     sal_uInt16			GetValue() const { return nValue; }
     const SfxType*  GetType() const { return pType; }
     const char*		GetUnoName() const { return pUnoName; }
-    SFX2_DLLPUBLIC rtl::OString    GetCommand() const;
-    SFX2_DLLPUBLIC rtl::OUString    GetCommandString() const;
 
     sal_uInt16			GetFormalArgumentCount() const { return nArgDefCount; }
     const SfxFormalArgument& GetFormalArgument( sal_uInt16 nNo ) const
diff --git a/sfx2/inc/sfx2/new.hxx b/sfx2/inc/sfx2/new.hxx
index bce4293..eb438ec 100644
--- a/sfx2/inc/sfx2/new.hxx
+++ b/sfx2/inc/sfx2/new.hxx
@@ -82,9 +82,8 @@ public:
     SfxNewFileDialog(Window *pParent, sal_uInt16 nFlags = 0);
     ~SfxNewFileDialog();
 
-        // Liefert sal_False, wenn '- Keine -' als Vorlage eingestellt ist
-        // Nur wenn IsTemplate() sal_True liefert, koennen Vorlagennamen
-        // erfragt werden
+    // Returns sal_False, when '- No -' is set as Template
+    // Template names can only be obtained when IsTemplate() returns sal_True.
     sal_Bool IsTemplate() const;
     String GetTemplateRegion() const;
     String GetTemplateName() const;
diff --git a/sfx2/inc/sfx2/objsh.hxx b/sfx2/inc/sfx2/objsh.hxx
index 50ab650..30c4361 100644
--- a/sfx2/inc/sfx2/objsh.hxx
+++ b/sfx2/inc/sfx2/objsh.hxx
@@ -93,7 +93,7 @@ class Point;
 
 // From embobj.hxx
 #define ASPECT_CONTENT      1
-#define ASPECT_THUMBNAIL    2 /* 120 * 120, 6 Farben DIB in MetaFile */
+#define ASPECT_THUMBNAIL    2 /* 120 * 120, 6 Colors DIB in MetaFile */
 #define ASPECT_ICON         4
 #define ASPECT_DOCPRINT     8
 #define ASPECT_ALL      (ASPECT_CONTENT | ASPECT_THUMBNAIL | ASPECT_ICON | ASPECT_DOCPRINT)
@@ -148,7 +148,7 @@ typedef sal_uInt32 SfxObjectShellFlags;
 #define SFX_TITLE_CAPTION  5
 #define SFX_TITLE_PICKLIST 6
 #define SFX_TITLE_HISTORY  7
-#define SFX_TITLE_MAXLEN   10   // ab hier sind das L"angenbegrenzungen
+#define SFX_TITLE_MAXLEN   10   // this gives the limits on length
 
 #define SFX_LOADED_MAINDOCUMENT 1
 #define SFX_LOADED_IMAGES       2
@@ -182,9 +182,9 @@ enum SfxObjectCreateMode
 
 /*====================================================================
 
-Die Klasse SfxObjectShell ist die Basisklasse f"ur SFx-Objekte, also
-f"ur Dokumente und Teile von Dokumenten, die als selbst"andige Objekte
-in fremde Objekte integriert werden k"onnen.
+The class SfxObjectShell is the base class for SFx-objects, ie documents 
+and parts of documents that can be integrated as separate objects 
+into foreign objects.
 
 ----------------------------------------------------------------------*/
 
@@ -199,13 +199,15 @@ friend struct ModifyBlocker_Impl;
 friend class SfxObjectShellLock;
 
 private:
-    struct SfxObjectShell_Impl* pImp;				// interne Daten
+    struct SfxObjectShell_Impl* pImp;     // internal data
 
-    SfxMedium * 				pMedium;			// Beschreibung der Datei bzw. des Storage, in dem sich das Objekt befindet
+    SfxMedium *                 pMedium;  // Description of the file for example 
+                                          // storage that contains the object
     SfxStyleSheetBasePool*		pStyleSheetPool;	// StyleSheets
-    SfxObjectCreateMode 		eCreateMode;		// Zweck des Objekts
-    sal_Bool					bHasName :1,		// sal_True := bestehendes Objekt, sal_False := es ist ein neues Objekt
-                                bIsTmp :1;          // temp. Storage
+    SfxObjectCreateMode         eCreateMode;      // Purpose of the object
+    sal_Bool                    bHasName :1,      // sal_True  := existing object, 
+                                                  // sal_False := new object
+                                bIsTmp :1;        // temporary Storage
 
 private:
     SAL_DLLPRIVATE void UpdateTime_Impl(const ::com::sun::star::uno::Reference<
@@ -465,7 +467,7 @@ public:
     // Naming Interface
     void                        SetTitle( const String& rTitle );
     String						GetTitle( sal_uInt16 nMaxLen = 0 ) const;
-    void						InvalidateName();	// Zuruecksetzen auf unbenannt
+    void                        InvalidateName();  // Re-set to unnamed
 
     // DDE-Interface
     virtual long				DdeExecute( const String& rCmd );
@@ -482,10 +484,10 @@ public:
 
     // Contents
     virtual SfxStyleSheetBasePool*	GetStyleSheetPool();
-    void					SetStyleSheetPool( SfxStyleSheetBasePool *pBasePool ) {
+    void                     SetStyleSheetPool(SfxStyleSheetBasePool *pBasePool ) {
                                         pStyleSheetPool = pBasePool; }
 
-    //determine the position of the "Automatic" filter in the stylist
+    // Determine the position of the "Automatic" filter in the stylist
     void                        SetAutoStyleFilterIndex(sal_uInt16 nSet);
     sal_uInt16                  GetAutoStyleFilterIndex();
     virtual sal_Bool            HasBasic() const;
@@ -496,7 +498,7 @@ public:
                                 GetDialogContainer();
     StarBASIC*					GetBasic() const;
 
-    // Interface Dok-Inhalte, Organizer
+    // Interface Document content, Organizer
 #define INDEX_IGNORE USHRT_MAX
 
 #define CONTENT_STYLE 0
@@ -550,18 +552,18 @@ public:
     void                        ReadNote( INote * );
     void                        UpdateNote( INote * );
 
-                                // F"ur Docs, die zum Formatieren die Viewgr"o\se
-                                // ben"otigen
+                                // Documents, for which to format the view size
+
     virtual SfxObjectShell* 	GetObjectShell();
 
     virtual SfxFrame*      		GetSmartSelf( SfxFrame* pSelf, SfxMedium& rMedium );
 
     ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel >
                                 GetModel() const;
-    // Nur uebergangsweise fuer die Applikationen !!!
+    // Only temporarily for the applications! 
     void						SetBaseModel( SfxBaseModel* pModel );
     ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel >	GetBaseModel() const;
-    // Nur uebergangsweise fuer die Applikationen !!!
+    // Only temporarily for the applications! 
 
     virtual ::com::sun::star::uno::Sequence< ::rtl::OUString > GetEventNames();
 
@@ -710,7 +712,7 @@ public:
     SAL_DLLPRIVATE void ExecView_Impl(SfxRequest &);
     SAL_DLLPRIVATE void StateView_Impl(SfxItemSet &);
 
-    // Laden-speichern public internals
+    // Load/Save public internals
     SAL_DLLPRIVATE sal_Bool ImportFromGeneratedStream_Impl(
                     const ::com::sun::star::uno::Reference< ::com::sun::star::io::XStream >& xStream,
                     const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& aMediaDescr );
diff --git a/sfx2/inc/sfx2/sfxhtml.hxx b/sfx2/inc/sfx2/sfxhtml.hxx
index 68182aa..d5335dd 100644
--- a/sfx2/inc/sfx2/sfxhtml.hxx
+++ b/sfx2/inc/sfx2/sfxhtml.hxx
@@ -48,9 +48,9 @@ class SFX2_DLLPUBLIC SfxHTMLParser : public HTMLParser
     String					aScriptType;
 
     SfxMedium*				pMedium;
-    SfxMedium *pDLMedium;	// Medium fuer Download von Files
+    SfxMedium *pDLMedium;   // Medium for Download Files
 
-    sal_uInt16 nMetaTags;		// Anzahl der bisher gelesenen Meta-Tags
+    sal_uInt16 nMetaTags;       // Number of previously read Meta-Tags
     ScriptType eScriptType;
 
     SAL_DLLPRIVATE void GetScriptType_Impl( SvKeyValueIterator* );
@@ -62,9 +62,9 @@ protected:
     virtual ~SfxHTMLParser();
 
 public:
-    // Lesen der Optionen einer Image-Map
-    // <MAP>: sal_True = Image-Map hat einen Namen
-    // <AREA>: sal_True = Image-Map hat jetzt einen Bereich mehr
+    // Read the options of an image map
+    // <MAP>: sal_True = Image-Map has a name
+    // <AREA>: sal_True = Image-Map has now one Region more
     static sal_Bool ParseMapOptions(ImageMap * pImageMap,
                                 const HTMLOptions * pOptions );
     sal_Bool ParseMapOptions(ImageMap * pImageMap)
@@ -83,35 +83,31 @@ public:
             const String& aNumStr, SvNumberFormatter& rFormatter );
 
 protected:
-
-    // Start eines File-Downloads. Dieser erfolgt synchron oder asynchron.
-    // Im synchronen Fall befindet sich der Parser nach dem Aufruf im
-    // Working-Zustand. Die gelesene Datei kann dann direkt mit
-    // FinishFileDownload abgeholt werden.
-    // Im asynchronen Fall befindet sich der Parser nach dem Aufruf im
-    // Pending-Zustand. Der Parser muss dann ueber das Continue verlassen
-    // werden (ohne Reschedule!). Wenn die Datei geladen ist, wird
-    // ein Continue mit dem uebergebenen Token aufgerufen. Die Datei kann
-    // dann wiederum mit FinishFileDownload abgeholt werden.
-    // Zum Abbrechen des Dwonloads sollte eine Shell uebergeben werden.
-    // Es kann nur ein einziger Download gleichzeitig existieren. Fuer jeden
-    // gestarteten Download muss FinshFileDownload aufgerufen werden.
+    // Start a file download. This is done asynchronously or synchronously. 
+    // In the synchronous case, the parser is in the the working state after 
+    // it has been called. The read file can then be picked up directly with 
+    // FinishFileDownload. In the asynchronous case, the parser is in the 
+    // pending state after it hs been called. The parser then has to leave 
+    // over the Continue (without Reschedule!). If the file is loaded, 
+    // a Continue is called with passed on token. The file can then be picked 
+    // up by FinishFileDownload. To cancel the download should a shell be 
+    // left. It can only exist a single download at the same time, For every 
+    // started download FinshFileDownload must be called.
     void StartFileDownload( const String& rURL, int nToken,
                             SfxObjectShell *pSh=0 );
 
-    // Beenden eines asynchronen File-Downloads. Gibt sal_True zurueck, wenn
-    // der Download geklappt hat. Das gelesene File befindet sich dann in
-    // dem uebergeben String.
+    // End of an asynchronous file download. Returns TRUE if the download 
+    // was successful. The read file is then passed into String.
     sal_Bool FinishFileDownload( String& rStr );
 
-    // Gibt sal_True zurueck, wenn ein File downloaded wurde und
-    // FileDownloadFinished noch nicht gerufen wurde.
+    // Returns TRUE if a file was downloaded and if FileDownloadFinished 
+    // has not yet been called
     sal_Bool ShouldFinishFileDownload() const { return pDLMedium != 0; }
 
     SfxMedium *GetMedium() { return pMedium; }
     const SfxMedium *GetMedium() const { return pMedium; }
 
-    // Default (auch ohne Iterator) ist JavaScript
+    // Default (without iterator) is JavaScript
     ScriptType GetScriptType( SvKeyValueIterator* ) const;
     const String& GetScriptTypeString( SvKeyValueIterator* ) const;
 };
diff --git a/sfx2/inc/sfx2/sfxsids.hrc b/sfx2/inc/sfx2/sfxsids.hrc
index 07325de..d0456cc 100755
--- a/sfx2/inc/sfx2/sfxsids.hrc
+++ b/sfx2/inc/sfx2/sfxsids.hrc
@@ -65,7 +65,7 @@
 #define SID_SETUPPRINTER                    (SID_SFX_START + 302)
 #define SID_EXITANDRETURN                   (SID_SFX_START + 303)
 
-// SID_TITLE steht unter diesem Wert in chaos/cntids.hrc!!
+// SID_TITLE, this value below is given in chaos/cntids.hrc!!
 //#define SID_TITLE			    (SID_SFX_START + 307)
 
 #define SID_CONTEXT                         (SID_SFX_START + 310)
@@ -108,7 +108,7 @@
 #define SID_PROGFILENAME                    (SID_SFX_START + 342)
 #define SID_SELECTION                       (SID_SFX_START + 346)
 
-// 360-400 siehe SID_MAIL_...
+// 360-400 see SID_MAIL_...
 
 // default-ids for help
 #define SID_HELPONHELP                      (SID_SFX_START + 400)
@@ -186,7 +186,7 @@
 #define SID_BROWSER                         (SID_SFX_START + 1318)
 #define SID_MACROEXECMODE                   (SID_SFX_START + 1319)
 
-// die Id steht mit diesem Wert in chaos/cntids.hrc!!
+// The Id value is given in chaos/cntids.hrc!!
 //#define SID_INTERNET_ONLINE		(SID_SFX_START + 1370)
 
 #define SID_FILTER_DATA                     (SID_SFX_START + 1375)
@@ -380,7 +380,7 @@
 #define SID_JSCALL                          (SID_SFX_START + 1382)
 #define SID_AUTOPILOTMENU                   (SID_SFX_START + 1381)
 
-// Floating Window Vorlagen
+// Floating Window Template
 #define SID_STYLE_DESIGNER                  (SID_SFX_START + 539)
 
 // Organizer
@@ -500,7 +500,7 @@
 #define SID_COPY                            (SID_SFX_START + 711)
 #define SID_PASTE                           (SID_SFX_START + 712)
 
-// steht unter diesem Wert in chaos/cntids.hrc!!!
+// Value below given in chaos/cntids.hrc!!!
 //#define SID_DELETE                (SID_SFX_START + 713)
 
 #define SID_BACKSPACE                       (SID_SFX_START + 714)
@@ -583,7 +583,7 @@
 #define SID_AUTOHIDE                        (SID_SFX_START + 932)
 #define SID_TOGGLENAVBAR					(SID_SFX_START + 1603)
 
-// Item-Id f"ur die Ereigniszuweisen-Tabpage
+// Item-Id for the assinged event Tabpage
 #define SID_ATTR_MACROITEM                  (SID_SFX_START + 934)
 
 #define SID_SAVECONFIG                      (SID_SFX_START + 930)
@@ -830,7 +830,7 @@
 #define SID_SAVEREL_INET                (SID_OPTIONS_START + 30)
 #define SID_SAVEREL_FSYS                (SID_OPTIONS_START + 31)
 
-// Automatisches update von Styles - Verwalten-TabPage
+// Automatic update of Styles - manage TabPage
 #define SID_ATTR_AUTO_STYLE_UPDATE      (SID_OPTIONS_START + 65)
 
 #define SID_SECURE_URL                  (SID_OPTIONS_START + 66)
@@ -887,7 +887,7 @@
 #define FID_SVX_START                       (SID_LIB_START + 500)
 #define FID_SEARCH_NOW                      (FID_SVX_START + 2)
 
-// SlotIds f"ur Basic -------------------------------------------------------
+// SlotIds for Basic -------------------------------------------------------
 #define SID_BASICIDE_TOGGLEBRKPNT           ( SID_BASICIDE_START +  0 )
 #define SID_BASICIDE_ADDWATCH               ( SID_BASICIDE_START +  1 )
 #define SID_BASICIDE_APPEAR                 ( SID_BASICIDE_START + 15 )
@@ -938,7 +938,7 @@
 #define SID_BASICIDE_MANAGE_LANG            ( SID_BASICIDE_START + 52 )
 #define SID_BASICIDE_CURRENT_LANG			( SID_BASICIDE_START + 53 )
 
-// SlotIds f"ur Apps --------------------------------------------------------
+// SlotIds for Apps --------------------------------------------------------
 #define FN_PARAM                            (SID_SW_START + 1100)
 #define FN_PARAM_1                          (FN_PARAM+60)
 #define FN_PARAM_2                          (FN_PARAM+61)
@@ -948,7 +948,7 @@
 #define FN_PARAM_6                          (FN_PARAM+65)
 #define FN_PARAM_7                          (FN_PARAM+66)
 #define FN_PARAM_8                          (FN_PARAM+67)
-#define FN_FAX                              (SID_SW_START + 28)   /* Faxen */
+#define FN_FAX                              (SID_SW_START + 28)   /* Fax */
 
 #define SID_KEYFUNC_START                   (SID_SC_START + 521)
 #define SID_CURSORDOWN_SEL                  (SID_KEYFUNC_START + 0)
diff --git a/sfx2/inc/sfx2/tabdlg.hxx b/sfx2/inc/sfx2/tabdlg.hxx
index 8115dfb..dff6017 100644
--- a/sfx2/inc/sfx2/tabdlg.hxx
+++ b/sfx2/inc/sfx2/tabdlg.hxx
@@ -58,7 +58,7 @@ class SfxBindings;
 #endif /* !ENABLE_LAYOUT_SFX_TABDIALOG*/
 
 typedef SfxTabPage* (*CreateTabPage)(Window *pParent, const SfxItemSet &rAttrSet);
-typedef sal_uInt16*		(*GetTabPageRanges)(); // liefert internationale Which-Wert
+typedef sal_uInt16*     (*GetTabPageRanges)(); // provides international Which-value
 struct TabPageImpl;
 class SfxUs_Impl;
 
@@ -122,9 +122,9 @@ friend class SfxTabDialogController;
 
 protected:
     virtual short				Ok();
-    // wird im Sfx gel"oscht!
+    // Is deleted in Sfx!
     virtual SfxItemSet*			CreateInputItemSet( sal_uInt16 nId );
-    // wird *nicht* im Sfx gel"oscht!
+    // Is not deleted in Sfx!
     virtual const SfxItemSet*	GetRefreshedSet();
     virtual void				PageCreated( sal_uInt16 nId, SfxTabPage &rPage );
     virtual long                Notify( NotifyEvent& rNEvt );
@@ -152,18 +152,18 @@ public:
 
     void				AddTabPage( sal_uInt16 nId,
                                     CreateTabPage pCreateFunc,		// != 0
-                                    GetTabPageRanges pRangesFunc,	// darf 0 sein
+                                    GetTabPageRanges pRangesFunc,	// can be 0
                                     sal_Bool bItemsOnDemand = sal_False);
     void				AddTabPage( sal_uInt16 nId,
                                     const String &rRiderText,
                                     CreateTabPage pCreateFunc,		// != 0
-                                    GetTabPageRanges pRangesFunc,	// darf 0 sein
+                                    GetTabPageRanges pRangesFunc,	// can be 0
                                     sal_Bool bItemsOnDemand = sal_False,
                                     sal_uInt16 nPos = TAB_APPEND);
     void				AddTabPage( sal_uInt16 nId,
                                     const Bitmap &rRiderBitmap,
                                     CreateTabPage pCreateFunc,		// != 0
-                                    GetTabPageRanges pRangesFunc,	// darf 0 sein
+                                    GetTabPageRanges pRangesFunc,	// can be 0
                                     sal_Bool bItemsOnDemand = sal_False,
                                     sal_uInt16 nPos = TAB_APPEND);
 
@@ -185,7 +185,7 @@ public:
                             { return aTabCtrl.GetCurPageId(); }
     void				ShowPage( sal_uInt16 nId );
 
-                        // liefert ggf. per Map konvertierte lokale Slots
+    // may provide local slots converted by Map
     const sal_uInt16*		GetInputRanges( const SfxItemPool& );
     void				SetInputSet( const SfxItemSet* pInSet );
     const SfxItemSet*	GetOutputItemSet() const { return pOutSet; }
@@ -284,12 +284,11 @@ public:
                             { bHasExchangeSupport = bNew; }
 
     enum sfxpg {
-        KEEP_PAGE = 0x0000,		// Fehlerbehandlung; Seite nicht wechseln
-            // 2. F"ullen eines ItemSets f"ur die Aktualilsierung
-            // "ubergeordneter Beispiele; dieser Pointer kann immer
-            // NULL sein!!
+      KEEP_PAGE = 0x0000,      // Error handling; page does not change
+        // 2. Fill an itemset for update 
+        // parent examples, this pointer can be NULL all the time!
         LEAVE_PAGE = 0x0001,
-            // Set aktualisieren und andere Page aktualisieren
+        // Set, refresh and update other Page
         REFRESH_SET = 0x0002
     };
 
diff --git a/sfx2/inc/sfx2/tbxctrl.hxx b/sfx2/inc/sfx2/tbxctrl.hxx
index c679090..3049116 100644
--- a/sfx2/inc/sfx2/tbxctrl.hxx
+++ b/sfx2/inc/sfx2/tbxctrl.hxx
@@ -104,9 +104,9 @@ class SfxFrameStatusListener : public svt::FrameStatusListener
 
 //------------------------------------------------------------------
 
-/*	FloatingWindows, die aus ToolBoxen abgerissen werden k"onnen, sollten
-    dieser Klasse abgeleitet werden. Da sie ebenfalls von SfxControllerItem
-    abgeleitet ist, erhalten ihre Instanzen auch die StateChanged Aufrufe.
+/* Floating windows that can be torn from tool boxes should be derived from 
+   this class. Since it is also derived from SfxControllerItem, its instances
+   will also receive the StateChanged calls. 
 */
 
 class SFX2_DLLPUBLIC SfxPopupWindow: public FloatingWindow, public SfxStatusListenerInterface
@@ -183,14 +183,13 @@ public:
         static SfxToolBoxControl* CreateImpl( sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox &rTbx ); \
         static void RegisterControl(sal_uInt16 nSlotId = 0, SfxModule *pMod=NULL)
 
-/*	F"ur spezielle ToolBox-Controls, z.B. eine Font-Auswahl-Box oder
-    aus ToolBoxen abrei"sbare FloatingWindows mu"s passend zur Item-Subclass
-    eine Subclass von SfxTooBoxControl implementiert werden.
+/*  For special ToolBox controls, such as a font selection box or toolbox 
+    tear-off floating windows, an appropriate Item-Subclass of SfxTooBoxControl
+    has to be implemented.
 
-    Diese Klasse mu"s in SfxApplication::Init() mit der statischen Methode
-    RegisterControl() registriert werden. Der SFx erzeugt dann automatisch
-    diese Controls in ToolBoxen, wenn die dazugeh"origen Slots von dem
-    angegebenen Typ sind.
+    This class has to be registered in SfxApplication:Init() with the static 
+    control method RegisterControl(). The SFx then automatically creates these 
+    controls in the toolbox, if the associated slots are of the specific type.
  */
 
 struct SfxToolBoxControl_Impl;
@@ -337,10 +336,10 @@ public:
 
 class SfxAppToolBoxControl_Impl : public SfxToolBoxControl
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Interne Hilfsklasse f"ur um das Popup-Menu <AppMenu_Impl> unter Neu
-    im SDT zu starten.
+    Internal helper class for the pop-up menu <AppMenu_Impl> under new 
+    start in the SDT.
 */
 
 {
diff --git a/sfx2/inc/sfx2/viewsh.hxx b/sfx2/inc/sfx2/viewsh.hxx
index 049fabb..ba192a6 100644
--- a/sfx2/inc/sfx2/viewsh.hxx
+++ b/sfx2/inc/sfx2/viewsh.hxx
@@ -71,7 +71,7 @@ class Dialog;
 class Menu;
 class NotifyEvent;
 
-#define SFX_PRINTER_PRINTER			 1 	// ohne JOBSETUP => temporaer
+#define SFX_PRINTER_PRINTER               1  // without JOB SETUP => Temporary
 #define SFX_PRINTER_JOBSETUP    	 2
 #define SFX_PRINTER_OPTIONS      	 4
 #define SFX_PRINTER_CHG_ORIENTATION  8
@@ -92,7 +92,7 @@ enum SfxScrollingMode
     SCROLLING_DEFAULT
 };
 
-// "Geeicht" mit www.apple.com und Netscape 3.01
+// "Verified" using www.apple.com and Netscape 3.01
 #define DEFAULT_MARGIN_WIDTH 8
 #define DEFAULT_MARGIN_HEIGHT 12
 
@@ -100,19 +100,19 @@ enum SfxScrollingMode
 
 // 	@[SfxViewShell-Flags]
 
-#define SFX_VIEW_HAS_PRINTOPTIONS    0x0010 /*  Options-Button und Options-
-                                                Dialog im PrintDialog */
-#define SFX_VIEW_CAN_PRINT			 0x0020 /*  enabled Printing ohne Printer
-                                                erzeugen zu m"ussen */
-#define SFX_VIEW_NO_SHOW			 0x0040 /*  Window der ViewShell darf nicht
-                                                automatisch geshowed werden */
-#define SFX_VIEW_NO_NEWWINDOW		0x0100		/* keine weitere View erlauben */
+#define SFX_VIEW_HAS_PRINTOPTIONS  0x0010 /* Options-Button and Options-
+                                             Dialog in PrintDialog */
+#define SFX_VIEW_CAN_PRINT         0x0020 /* Printing enabled without having
+                                             to create a Printer */
+#define SFX_VIEW_NO_SHOW           0x0040 /* Window of the ViewShell shall
+                                             not be showed automatically */
+#define SFX_VIEW_NO_NEWWINDOW      0x0100 /* Allow N View */
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Die SfxViewShell-Flags steuern das Verhalten der SfxViewShell f"ur die
-    Dauer ihrer Lebenszeit. Sie werden im Konstruktor der <SfxViewShell>
-    angegeben.
+    The SfxViewShell flags control the behavior of SfxViewShell for the 
+    duration of its lifetime. They are defined in the constructor of 
+    <SfxViewShell>.
 */
 
 //=========================================================================
@@ -186,7 +186,7 @@ public:
 
     static SfxViewShell*        Get( const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XController>& i_rController );
 
-    // Ctoren/Dtoren Initialisierung
+    // Initialize Constructors/Destructors 
                                 TYPEINFO();
                                 SFX_DECL_INTERFACE(SFX_INTERFACE_SFXVIEWSH)
 
@@ -208,7 +208,7 @@ public:
     virtual void				JumpToMark( const String& rMark );
     void						VisAreaChanged(const Rectangle& rRect);
 
-    // Verhaltens-Flags
+    // Behavior Flags
     SfxScrollingMode			GetScrollingMode() const;
     void						SetScrollingMode( SfxScrollingMode eMode );
 
@@ -250,7 +250,7 @@ public:
     virtual JobSetup			GetJobSetup() const;
     Printer*                    GetActivePrinter() const;
 
-    // Workingset
+    // Working set
     virtual void                WriteUserData( String&, sal_Bool bBrowse = sal_False );
     virtual void                ReadUserData( const String&, sal_Bool bBrowse = sal_False );
     virtual void                WriteUserDataSequence ( ::com::sun::star::uno::Sequence < ::com::sun::star::beans::PropertyValue >&, sal_Bool bBrowse = sal_False );
@@ -338,19 +338,18 @@ public:
 
 inline void	SfxViewShell::LostFocus() const
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Diese Methode mu\s vom Applikationsentwickler gerufen werden, wenn
-    das Edit-Window den Focus verloren hat. Der SFx hat so z.B. die
-    M"oglichkeit, den Accelerator auszuschalten, damit in bestimmten
-    Floating-Windows die Cursor-Tasten, die Delete-Taste etc. funktionieren,
-    obwohl sie "uber den Accelerator umdefiniert sind.
+    This method has to be  called by the application developer, if the edit 
+    window has lost the focus. The SFx has for example the ability to turn off 
+    the accelerator, so that the cursor keys, the Delete button, etc. work in
+    certain Floating-Windows, even though they are redefined by the 
+    Accelerator.
 
+    [Note]
 
-    [Anmerkung]
-
-    <StarView> liefert leider keine M"oglichkeit, solche Events
-    'von der Seite' einzuh"angen.
+    <StarView> unfortunatly does not provide the possibility to define 
+    such events 'from the side'.
 */
 
 {
@@ -360,16 +359,14 @@ inline void	SfxViewShell::LostFocus() const
 
 inline SfxViewFrame* SfxViewShell::GetViewFrame() const
 
-/*	[Bechreibung]
-
-    Diese Methode liefert einen Pointer auf die <SfxViewFrame>-Instanz,
-    in der diese SfxViewShell dargestellt wird. Dieses ist die Instanz,
-    die imKonstruktor durchgereicht wurde. Es ist gew"ahrleistet, da\s
-    der zur"uckgegebene Pointer auf eine g"ultige SfxViewFrame-Instanz
-    zeigt.
+/*  [Description]
 
+    This method returns a pointer to the <SfxViewFrame> Instance in which 
+    this SfxViewShell is displayed. This is the instance that was passed 
+    on in the constructor. It is guaranteed that the returned pointer 
+    points on the valid SfxViewFrame instance.
 
-    [Querverweise]
+    [Cross-reference]
 
     <SfxShell::GetFrame()const>
 */
diff --git a/sfx2/source/dialog/styledlg.cxx b/sfx2/source/dialog/styledlg.cxx
index 46796c6..555f3a9 100644
--- a/sfx2/source/dialog/styledlg.cxx
+++ b/sfx2/source/dialog/styledlg.cxx
@@ -59,8 +59,8 @@ SfxStyleDialog::SfxStyleDialog
 
     SfxTabDialog( pParent, rResId,
                   rStyle.GetItemSet().Clone(),
-                  // auch ohne ParentSupport TRUE "ubergeben, aber erweitert
-                  // um den StandardButton zu unterdr"ucken
+                  // return TRUE also without ParentSupport , but extended 
+                  // to suppress the standardButton 
                   rStyle.HasParentSupport() ? sal_True : 2,
                   pUserBtnTxt ),
 
diff --git a/sfx2/source/dialog/tabdlg.cxx b/sfx2/source/dialog/tabdlg.cxx
index ef8e49d..1b3fa54 100644
--- a/sfx2/source/dialog/tabdlg.cxx
+++ b/sfx2/source/dialog/tabdlg.cxx
@@ -1559,7 +1559,6 @@ const SfxItemSet* SfxTabDialog::GetOutputItemSet
 
 (
     sal_uInt16 nId  // the Id, under which the page was added at AddTabPage().
-                // hinzugefügt wurde.
 ) const
 {
     Data_Impl* pDataObject = Find( *pImpl->pData, nId );
diff --git a/sfx2/source/doc/objxtor.cxx b/sfx2/source/doc/objxtor.cxx
index 57c1eb2..3dba18f 100644
--- a/sfx2/source/doc/objxtor.cxx
+++ b/sfx2/source/doc/objxtor.cxx
@@ -201,7 +201,7 @@ void SAL_CALL SfxModelListener_Impl::disposing( const com::sun::star::lang::Even
         mpDoc->OwnerLock(sal_False);
     }
     else if ( !mpDoc->Get_Impl()->bClosing )
-        // GCC stuerzt ab, wenn schon im dtor, also vorher Flag abfragen
+        // GCC crashes when already in the destructor, so first query the Flag 
         mpDoc->DoClose();
 }
 
diff --git a/sfx2/source/view/frame.cxx b/sfx2/source/view/frame.cxx
index 9381655..7b429e5 100644
--- a/sfx2/source/view/frame.cxx
+++ b/sfx2/source/view/frame.cxx
@@ -48,7 +48,7 @@
 #include <comphelper/processfactory.hxx>
 #include <vcl/msgbox.hxx>
 
-// wg. pTopFrames
+// due to pTopFrames
 #include "appdata.hxx"
 #include <sfx2/app.hxx>
 #include <sfx2/event.hxx>


More information about the Libreoffice-commits mailing list
diff --git a/sfx2/inc/sfx2/bindings.hxx b/sfx2/inc/sfx2/bindings.hxx
index 3d0da52..50e45cc 100644
--- a/sfx2/inc/sfx2/bindings.hxx
+++ b/sfx2/inc/sfx2/bindings.hxx
@@ -70,12 +70,12 @@ SV_DECL_PTRARR( SfxUnoControllerArr_Impl, SfxUnoControllerItemPtr, 20, 20 )
 //	defines
 //________________________________________________________________________________________________________________
 
-#define SFX_CALLMODE_SLOT           0x00    // sync/async vom Slot
-#define SFX_CALLMODE_SYNCHRON		0x01    // synchron im selben Stackframe
-#define SFX_CALLMODE_ASYNCHRON		0x02    // asynchron per AppEvent
-#define SFX_CALLMODE_RECORD			0x04    // beim Recorden ber"ucksichtigen
-#define SFX_CALLMODE_API        	0x08    // Call von der API (silent)
-#define SFX_CALLMODE_MODAL	     	0x10    // trotz ModalMode
+#define SFX_CALLMODE_SLOT               0x00    // sync/async from Slot
+#define SFX_CALLMODE_SYNCHRON           0x01    // synchronously in the same Stackframe
+#define SFX_CALLMODE_ASYNCHRON          0x02    // asynchronously via AppEvent
+#define SFX_CALLMODE_RECORD             0x04    // take into accont while recording
+#define SFX_CALLMODE_API                0x08    // API call (silent)
+#define SFX_CALLMODE_MODAL              0x10    // despite ModalMode
 
 #define SFX_CALLMODE_STANDARD       SFX_CALLMODE_RECORD
 typedef sal_uInt16 SfxCallMode;
@@ -90,23 +90,22 @@ enum SfxPopupAction
 //====================================================================
 class SFX2_DLLPUBLIC SfxBindings: public SfxBroadcaster
 
-/*	[Beschreibung]
-
-    In jeder SFx-Applikation existiert "uber die Laufzeit von vor
-    <SfxApplication::Init()> bis nach <SfxApplication::Exit()> eine Instanz
-    der Klasse SfxBindings. Sie wird von der SfxApplication automatisch
-    angelegt und zerst"ort. Instanzen werden aber i.d.R. "uber das
-    Makro <SFX_BINDINGS> oder den zugeh"origen <SfxViewFrame> besorgt
-    werden.
-
-    Die SfxBindings verwalten alle in den an ihr angemeldeten Controllern
-    gebundenen Slot-Ids und cachen die jeweiligen <Slot-Server>
-    (so nenne wir die Kombination aus SfxShell-Instanz und SfxSlot).
-    In den SfxBindings ist gespeichert, ob und welche Controller dirty
-    sind sowie welche Slot-Server-Caches jeweils dirty sind. Sie fa"st
-    Status-Anfragen (Aufrufe der in der IDL genannten Status-Methoden)
-    zusammen, die von derselben Status-Methode bedient werden, und sorgt
-    f"ur die Simulation der <Pseudo-Slots>.
+/*  [Description]
+
+    In each SFx application one instance of the SfxBindings-Class will
+    exists from <SfxApplication::Init()> until <SfxApplication::Exit()>.
+    This instance is automatically created and destroyed by SfxApplication.
+    However these instances will be handled by the Macro <SFX_BINDINGS>
+    or the associated <SfxViewFrame>.
+
+    The SfxBindings manages all of its Slot-Ids bound by the registerd
+    controllers and keeps a cache of the <Slot-Server> respectively.
+    (it is what we call the combination of SfxShell instance and SfxSlot).
+    In the SfxBindings it is stored, if and in this case which controllers
+    that are dirty and which Slot-Server-Caches are dirty respectively.
+    It summarizes status queries (calls to the status methods specified
+    in the IDL) that are served by the same state methods, and handles
+    the simulation of <Pseudo-Slots>.
 */
 
 {
@@ -114,15 +113,15 @@ friend class SfxApplication;
 friend class SfxShell;
 friend class SfxBindings_Impl;
 
-    SfxBindings_Impl*pImp;			// Daten der Bindings-Instanz
-    SfxDispatcher*	 pDispatcher;	// zu verwendender Dispatcher
-    sal_uInt16       nRegLevel;      // Lock-Level waehrend Reconfig
+    SfxBindings_Impl*pImp;           // Data of the Bindings instance
+    SfxDispatcher*   pDispatcher;    // Dispatcher, to be used
+    sal_uInt16       nRegLevel;      // Lock-Level while Reconfig
 
 private:
     SAL_DLLPRIVATE const SfxPoolItem*  Execute_Impl( sal_uInt16 nSlot, const SfxPoolItem **pArgs, sal_uInt16 nModi,
                                     SfxCallMode nCall, const SfxPoolItem **pInternalArgs, sal_Bool bGlobalOnly=sal_False);
     SAL_DLLPRIVATE void SetSubBindings_Impl( SfxBindings* );
-    SAL_DLLPRIVATE void UpdateSlotServer_Impl(); // SlotServer aktualisieren
+    SAL_DLLPRIVATE void UpdateSlotServer_Impl(); // Update SlotServer
     SAL_DLLPRIVATE SfxItemSet* CreateSet_Impl( SfxStateCache* &pCache,
                                     const SfxSlot* &pRealSlot,
                                     const SfxSlotServer**,
@@ -145,7 +144,7 @@ public:
 
     void			 SetDispatcher(SfxDispatcher *pDisp);
 
-    void			 Update( sal_uInt16 nId ); // z.B. aus Menu::Activate
+    void             Update( sal_uInt16 nId ); // For example, from  Menu::Activate
     void			 Update();
     SAL_DLLPRIVATE void StartUpdate_Impl(sal_Bool bComplete=sal_False);
     void			 Invalidate( sal_uInt16 nId );
@@ -232,21 +231,21 @@ public:
 
 inline int SfxBindings::IsInRegistrations() const
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Stellt fest, ob an der SfxBindings Instanz gerade <SfxContollerItems>
-    an- oder abgemeldet werden, also noch <SfxBindings::EnterRegistrations()>
-    Aufrufe nicht mit <SfxBindings::EnterRegistrations()> geschlo"sen wurden.
+    Determines whether the <SfxContollerItems> SfxBindings instance is
+    registerd or unregisted, i.e. <SfxBindings::EnterRegistrations()>
+    calls that have not been closed by <SfxBindings::LeaveRegistrations()>.
 
-    [R"uckgabewert]
+    [Return value]
 
     int 				sal_True
-                        Die SfxBindings Instanz ist gerade im Registrierungs-
-                        Modus. Es erfolgen also keine Status-Updates.
+                        The SfxBindings instance is currently in
+                        Registration-Mode. No status updates .
 
-                        sal_False
-                        Die SfxBindings Instanz ist gerade im normalen
-                        Modus. Es k"oennen also Status-Updates erfolgen.
+    int sal_False
+                        The SfxBindings instance is the normal mode.
+                        Status updates can be done.
 */
 
 {